-- The ActionLog table schema
-- $Id: actionlog.sql,v 1.1.1.1 2008/03/03 17:50:31 aarefyev Exp $
-- $Log: actionlog.sql,v $
-- Revision 1.1.1.1  2008/03/03 17:50:31  aarefyev
-- initial import
--
-- Revision 1.1  2005/11/15 10:41:44  mansoor
-- persistent actionlog schema
--

CREATE SEQUENCE actionlog_id_seq INCREMENT 1 START 1;

CREATE TABLE actionlog (
-- The number that identifies a sequence of actions. 
-- This would identify all the actionlog messages that have been logged during a particular request processing
    id          INT PRIMARY KEY NOT NULL DEFAULT NEXTVAL('actionlog_id_seq'),

-- The parent id of this message. This causes several messages to be grouped under one heading
    parent_id   INT DEFAULT 0,

-- The log level. The significance is DEBUG=0/INFO=1/WARNING=2/EXCEPTION=3/ERROR=4/FATAL=5
    loglevel    INT NOT NULL DEFAULT 0,

-- The name of the logged in user
    username    VARCHAR(1024),

-- The role of the logged in user. Can be either of 'isp', 'reseller', 'site', or 'user'
    role        VARCHAR(16),

-- The actual log message
    message     VARCHAR(1024),

-- The stringified version of the pythonic format args which should be applied to the message before rendering
    params      BYTEA,

-- These next 3 fields are passed to the info/warn/error methods, but I don't think they are necessary
--    action      VARCHAR(1024),
--    stage     VARCHAR(1024),
--    service     VARCHAR(1024),

-- Indicates whether the whole sequence of actions has been completed. Useful to know when to stop polling. 
-- This field is only significant if the id is not 0
    completed   BOOLEAN DEFAULT (false),

-- The time when this message was logged
    ts          TIMESTAMP WITHOUT TIME ZONE DEFAULT ('now'::text)::timestamp(6) WITH TIME ZONE
);

