<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:fn="http://www.w3.org/2005/02/xpath-functions"
    xmlns:epl="http://www.ensim.com/epl50"
    xmlns:math="http://exslt.org/math"
    xmlns:sets="http://exslt.org/sets"
    xmlns:func="http://exslt.org/functions"
    extension-element-prefixes="func"
>

<xsl:output method="xml" indent="yes" />

<!-- This is the ISP Administrator's Dashboard XSL
     The ISP Administrator's Dashboard ($frontend/static/isp/dashboard.xml) will be passed to this
-->

<!-- This function gets an item node and checks if that node is to be displayed on the dashboard or
not. For this it checks if the service of that item is enabled or not. If no service node is present
or if service node is empty then it displays the item.
-->
<func:function name="func:isItemDisplayable">
 <xsl:param name="item_node"/>
 <xsl:variable name="ispro" select="epl:isPro()"/>
 <xsl:variable name="service" select="$item_node/service/text()"/>
 <xsl:choose>
  <xsl:when test="$item_node/child::node()[name() = 'proenabled']">
   <xsl:choose>
    <xsl:when test="$ispro = 'False'">
     <func:result select="false()"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:choose>
      <xsl:when test="$item_node/child::node()[name() = 'service'] and $item_node/service/text()">
       <xsl:choose>
        <xsl:when test="/ispdashboard/enabledservices/child::node()[name() = $service]">
         <func:result select="true()"/>
        </xsl:when>
        <xsl:otherwise>
         <func:result select="false()"/>
        </xsl:otherwise>
       </xsl:choose>
      </xsl:when>
      <xsl:otherwise>
       <func:result select="true()"/>
      </xsl:otherwise>
     </xsl:choose>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:when>
  <xsl:otherwise>
   <xsl:choose>
    <xsl:when test="$item_node/child::node()[name() = 'basicenabled']">
     <xsl:choose>
      <xsl:when test="$ispro = 'True'">
       <func:result select="false()"/>
      </xsl:when>
      <xsl:otherwise>
       <xsl:choose>
	<xsl:when test="$item_node/child::node()[name() = 'service'] and $item_node/service/text()">
	 <xsl:choose>
	  <xsl:when test="/ispdashboard/enabledservices/child::node()[name() = $service]">
	   <func:result select="true()"/>
	  </xsl:when>
	  <xsl:otherwise>
	   <func:result select="false()"/>
	  </xsl:otherwise>
	 </xsl:choose>
	</xsl:when>
	<xsl:otherwise>
	 <func:result select="true()"/>
	</xsl:otherwise>
       </xsl:choose>
      </xsl:otherwise>
     </xsl:choose>
    </xsl:when>
    <xsl:otherwise> 
     <xsl:choose>
      <xsl:when test="$item_node/child::node()[name() = 'service'] and $item_node/service/text()">
       <xsl:choose> 
	<xsl:when test="/ispdashboard/enabledservices/child::node()[name() = $service]">
	 <func:result select="true()"/>
	</xsl:when>
	<xsl:otherwise>
	 <func:result select="false()"/>
	</xsl:otherwise>
       </xsl:choose> 
      </xsl:when>
      <xsl:otherwise>
       <func:result select="true()"/> 
      </xsl:otherwise>
     </xsl:choose>
    </xsl:otherwise> 
   </xsl:choose>
  </xsl:otherwise>
 </xsl:choose>
</func:function>

<!-- This iterates over each item node in the current select and calls isItemDisplayable() function
for each item.
-->
<xsl:key name="displayItem" match="item" use="func:isItemDisplayable(.)"/>

<!-- This function checks if a section is to be displayed on the dashboard. A section has to be
displayed if there is even one item under it which is displayable.
-->
<func:function name="func:isSectionDisplayable">
 <xsl:param name="section_node"/>
 <xsl:choose>
  <xsl:when test="count(key('displayItem','true')[../caption/text() = $section_node/caption/text()]) = 0">
   <func:result select="false()"/>
  </xsl:when>
  <xsl:otherwise>
   <func:result select="true()"/>
  </xsl:otherwise>
 </xsl:choose>
</func:function>

<xsl:template match="/">
 <xsl:variable name="isp_dashboard_title" select="/ispdashboard/title/text()"/>
 <xsl:variable name="num_columns" select="/ispdashboard/columns/text()"/>
 <xsl:variable name="num_sections" select="count (/ispdashboard/section)"/>

 <!-- note: the `round' function rounds off the floating point number -->
 <xsl:variable name="num_rows" select="round ($num_sections div $num_columns)"/>

 <!-- see http://www.xml.com/pub/a/2001/05/07/xsltmath.html for some xsl math functions -->
 <xsl:variable name="section_width" select="floor (100 div $num_columns)"/>
 <xsl:variable name="section_height" select="floor (100 div $num_rows)"/>

 <html xmlns="http://www.w3.org/1999/xhtml">
  <head>
   <meta content="text/html; charset=ISO-8859-1" http-equiv="content-type" />
   <link href="/static/css/isp.global.css" type="text/css" rel="stylesheet" />
   <title><xsl:value-of select="epl:_(string(/ispdashboard/title/text()))"/></title>
   <script src="/static/js/motd.js" charset="utf-8" type="text/javascript">.</script>
  </head>

  <body onload="callMotd();">
   <span id="motd_message"><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></span>
    <!--<xsl:variable name="updatesAvailable" select="epl:updatesAvailable()"/>
    <xsl:if test="$updatesAvailable = 'True'">
        <p><b><lang>New updates are available. Click </lang><a href="/isp/listUpdates"><lang>here</lang></a><lang> to know more.</lang></b></p>
    </xsl:if>-->
   <table class="isp-dashboard" cellspacing="0">
    <tr>
     <td colspan="{$num_columns}" class="isp-dashboard-title"><div><xsl:value-of select="epl:_(string(/ispdashboard/title/text()))"/></div></td>
    </tr>

    <xsl:for-each select="/ispdashboard/section[func:isSectionDisplayable(.) = 'true']">
     <xsl:if test="(position() mod $num_columns) = 1">
      <!-- record the 1-based position of this element -->
      <tr>
       <xsl:for-each select=". | ./following-sibling::node()[(name() = 'section') and (func:isSectionDisplayable(.) = 'true')][position() &lt; $num_columns]">
        <td width="{$section_width}%" height="{$section_height}%">

         <!-- one table per section -->
         <table width="100%" height="100%"  cellspacing="0">

          <tr>
           <td class="isp-dashboard-section-top-l"></td>
           <td class="isp-dashboard-section-top"></td>
           <td class="isp-dashboard-section-top-r"></td>
          </tr>

          <tr>
	   <th class="isp-dashboard-section-left"></th>
           <!-- first row is the caption of the section -->
       	   <th class="isp-dashboard-section-head"><xsl:value-of select="epl:_(string(caption))"/></th>
	   <th class="isp-dashboard-section-right"></th>
          </tr>

          <tr>
	   <td class="isp-dashboard-section-left"></td>
           <!-- second row is the actual content of the section -->
           <td valign="center" class="isp-dashboard-section-contents">
            <xsl:variable name="section_img" select="image" />
            <img src="{$section_img}" class="db-icon" />
            <xsl:variable name="current_item" select="."/>
            <xsl:for-each select="key('displayItem','true')[generate-id(..) = generate-id($current_item)]">
             <xsl:variable name="url" select="link/text()"/>
             <p><a href="{$url}"><xsl:value-of select="epl:_(string(display/text()))"/></a></p>
            </xsl:for-each>
           </td>
	   <td class="isp-dashboard-section-right"></td>
          </tr>

          <tr>
           <td class="isp-dashboard-section-bottom-l"></td>
           <td class="isp-dashboard-section-bottom"></td>
           <td class="isp-dashboard-section-bottom-r"></td>
          </tr>

         </table>
        </td>

       </xsl:for-each>
      </tr>
     </xsl:if>
    </xsl:for-each>
   </table>
  </body>
 </html>

</xsl:template>
</xsl:stylesheet>
