<?xml version="1.0"?><!-- DWXMLSource="../xml/site.dashboard.xml" -->
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:func="http://exslt.org/functions"
  xmlns:epl="http://www.ensim.com/epl50"
  xmlns:dyn="http://exslt.org/dynamic"
  extension-element-prefixes="exsl func dyn">

<func:function name="func:B_to_MB">
  <xsl:param name="bytes"/>
  <func:result select="$bytes div 1048576"/>
</func:function>

<xsl:template name="join_toggle_nodes">
  <xsl:param name="toggleElements"/>
  <xsl:for-each select="exsl:node-set($toggleElements)/item">
    <token>'<xsl:value-of select="@name"/>'</token>
    <xsl:if test="position() != last()">
      <token>,</token>
    </xsl:if>
  </xsl:for-each>
</xsl:template>

<xsl:template name="search-and-replace">
  <xsl:param name="input"/>
  <xsl:param name="search-string"/>
  <xsl:param name="replace-string"/>
  <xsl:choose>
    
    <xsl:when test="$search-string and contains($input,$search-string)">
      <xsl:value-of select="substring-before($input,$search-string)"/>
      <xsl:value-of select="$replace-string"/>
      <xsl:call-template name="search-and-replace">
        <xsl:with-param name="input" select="substring-after($input, $search-string)"/>
        <xsl:with-param name="search-string" select="$search-string"/>
        <xsl:with-param name="replace-string" select="$replace-string"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="$input"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="drawMOTD">
  <table class="isp-dashboard-title">  
  <xsl:for-each select="//entry">
         <tr> 
             <td align= 'left'>
             <xsl:variable name="url" select="/site/motd/link/text()"/>
             <xsl:variable name="id" select="epl:_(string(id/text()))"/>
             <xsl:variable name="title" select="epl:_(string(title/text()))"/>
             <img src="/static/images/bullet1.gif"/>
             <xsl:text disable-output-escaping="yes">&amp;nbsp;&amp;nbsp;</xsl:text>
             <a href="javascript://" onclick="window.open('{$url}?id={$id}','glo','width=635,height=375,scrollbars,resizable')" target="_self"><xsl:value-of select="$title"/></a>
             </td>
         </tr>
  </xsl:for-each>
  </table>
</xsl:template>

<xsl:param name="locale" select="'en_US'"/>

<xsl:output method="html" omit-xml-declaration="yes" indent="yes"/>

<xsl:template match="site">
  <xsl:variable name="content">
	
		<xsl:call-template name="WebFullPane">
		  <xsl:with-param name="data" select="statistics"/>
		  <xsl:with-param name="root" select="."/>
		</xsl:call-template>
	
    <xsl:if test="statistics/sendmail">
			<xsl:call-template name="MailFullPane">
			  <xsl:with-param name="data" select="statistics"/>
			  <xsl:with-param name="root" select="."/>
			</xsl:call-template>
    </xsl:if>

	    <xsl:call-template name="SiteFullPane">
    	  <xsl:with-param name="data" select="statistics"/>
	    </xsl:call-template>    
  </xsl:variable>

  <xsl:call-template name="HTMLPage">
    <xsl:with-param name="content">
      <xsl:copy-of select="$content"/>
    </xsl:with-param>
  </xsl:call-template>
</xsl:template>

<xsl:template name="ConvertToSortedNameValue">
  <!-- returns a tree sorted by value -->
  <xsl:param name="list"/>
  <xsl:param name="name_field"/>
  <xsl:param name="value_field"/>
  <xsl:param name="sort_field"/>
  <xsl:param name="datatype" select="'number'"/>
  <xsl:param name="order" select="'descending'"/>
  <itemlist>
    <xsl:for-each select="$list">
      <xsl:sort select="*[name() = $sort_field]" data-type="{$datatype}" order="{$order}"/>
      <item>
        <name>
          <xsl:value-of select="*[name() = $name_field]"/>
        </name>
        <value>
          <xsl:value-of select="*[name() = $value_field]"/>
        </value>
        <data>
          <xsl:copy-of select="*"/>
        </data>
      </item>
    </xsl:for-each>
  </itemlist>
</xsl:template>

<xsl:template name="FullPaneHeaderRow">
  <xsl:param name="icon"/>
  <xsl:param name="caption"/>
  <xsl:param name="desc"/>
  <xsl:param name="columns"/>
  <tr>
    <td colspan="{$columns}" class="isp-dashboard-title-big"><div class="title-img"><img src="{$icon}"/></div><div><xsl:value-of select="$caption"/></div></td>
  </tr>
  <tr>
    <td colspan="{$columns}" class="isp-dashboard-title-desc"><div><xsl:value-of select="$desc"/></div></td>
  </tr>
</xsl:template>

<xsl:template name="NameValueListboxTable">
  <xsl:param name="list"/>
  <xsl:param name="id"/>
  <xsl:param name="process" select="'value'"/>
  <table width="100%" border="0" cellspacing="0" cellpadding="0">
    <tr>
      <td width="10%"></td>
      <td>
        <select multiple="multiple" rows="6" width="200" STYLE="width:200px;height:100px">
          <xsl:for-each select="exsl:node-set($list)/itemlist/item">
            <option>
              <xsl:value-of select="dyn:evaluate($process)"/>&#160;&#160;&#160;<xsl:value-of select="name"/>
            </option>
          </xsl:for-each>
        </select>
      </td>
    </tr>
  </table>
</xsl:template>

<xsl:template name="NameValueTable">
  <xsl:param name="list"/>
  <xsl:param name="id"/>
  <xsl:param name="limit"/>
  <xsl:param name="process" select="'value'"/>
  <xsl:param name="draw_link" select="''"/>
  <xsl:param name="priv_link" select="''"/>
  <xsl:param name="draw_test" select="1"/>
  <table width="100%" border="0" cellspacing="0" cellpadding="0">
    <xsl:for-each select="exsl:node-set($list)/itemlist/item[position() &lt;= $limit]">
      <xsl:variable name="eval_draw_test" select="dyn:evaluate($draw_test)"/>

      <tr>
        <td width="10%"></td>
        <td>
          <span>
            <xsl:choose>
              <xsl:when test="$draw_link and boolean($eval_draw_test)">
                <xsl:variable name="link" select="dyn:evaluate($draw_link)"/>
                <a href="{$link}"><xsl:value-of select="name"/></a>
              </xsl:when>
              <xsl:otherwise>
                <xsl:choose>
                  <xsl:when test="$priv_link">
                    <xsl:variable name="my_priv_link" select="dyn:evaluate($priv_link)"/>
                    <a href="{$my_priv_link}"><xsl:value-of select="name"/></a>
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:value-of select="name"/>
                  </xsl:otherwise>
                </xsl:choose>
              </xsl:otherwise>
            </xsl:choose>
          </span></td>
        <td><span class="right-align"><xsl:value-of select="dyn:evaluate($process)"/></span></td>
      </tr>
    </xsl:for-each>
  </table>
</xsl:template>

<xsl:template name="divToggle">
  <script language="JavaScript">
    function toggleDisplay(select_id, div_list) {
      selectList = document.getElementById(select_id);
      selectValue = selectList.options[selectList.selectedIndex].value;
      for (i in div_list) {
        target = document.getElementById(div_list[i]);
        if (div_list[i] != selectValue) {
          target.style.display = "none";
        } else {
          target.style.display = "inline";
        }
      }
    }
  </script>
</xsl:template>

<xsl:template name="DrawSelect">
  <xsl:param name="toggleList"/>
  <xsl:param name="toggleElements"/>
  <xsl:param name="name"/>
  <select name="{$name}" id="{$name}" onChange="toggleDisplay('{$name}', [{$toggleList}])">
    <xsl:for-each select="exsl:node-set($toggleElements)/item">
      <xsl:choose>
        <xsl:when test="@selected">
          <option value="{@name}" selected="selected">
            <xsl:value-of select="caption"/>
          </option>
        </xsl:when>
        <xsl:otherwise>
          <option value="{@name}">
            <xsl:value-of select="caption"/>
          </option>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:for-each>
  </select>
</xsl:template>

<xsl:template name="MailDetailsTables">
  <xsl:param name="data"/>

  <xsl:variable name="toggleElements">
    <xsl:if test="$data/sendmail/user_mailboxes">
      <xsl:variable name="sorted_user_list">
        <xsl:call-template name="ConvertToSortedNameValue">
          <xsl:with-param name="list" select="$data/sendmail/user_mailboxes/item"/>
          <xsl:with-param name="name_field" select="'user'"/>
          <xsl:with-param name="value_field" select="'mailbox'"/>
          <xsl:with-param name="sort_field" select="'mailbox'"/>
          <xsl:with-param name="datatype" select="'number'"/>
          <xsl:with-param name="order" select="'descending'"/>
        </xsl:call-template>
      </xsl:variable>
      <item name="top_mailboxes" selected="selected">
        <caption>
          <!--<xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'top mailbox sizes'"/>
          </xsl:call-template>-->
          <xsl:value-of select="epl:_('top mailbox sizes')"/>
        </caption>
        <content>
          <xsl:call-template name="NameValueTable">
            <xsl:with-param name="list" select="$sorted_user_list"/>
            <xsl:with-param name="id" select="'top_mailboxes'"/>
            <xsl:with-param name="limit" select="'6'"/>
            <!-- the 'process' var will be eval'ed in draw -->
            <xsl:with-param name="process">
              format-number(func:B_to_MB(value), '0.00')
            </xsl:with-param>
            <xsl:with-param name="draw_link">
              concat('/siteadmin/services/users/edit?username=', name)
            </xsl:with-param>
            <xsl:with-param name="priv_link">
              concat('/siteadmin/changeadmin','')
            </xsl:with-param>
            <xsl:with-param name="draw_test">
              1 - number(data/privileged)
            </xsl:with-param>
          </xsl:call-template>
        </content>
      </item>
      <item name="all_mailboxes">
        <caption>
          <!--<xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'all mailbox sizes'"/>
          </xsl:call-template>-->
          <xsl:value-of select="epl:_('all mailbox sizes')"/>
        </caption>
        <content>
          <xsl:call-template name="NameValueListboxTable">
            <xsl:with-param name="list" select="$sorted_user_list"/>
            <xsl:with-param name="id" select="'all_mailboxes'"/>
            <xsl:with-param name="process">
              format-number(func:B_to_MB(value), '0.00')
            </xsl:with-param>
          </xsl:call-template>
        </content>
      </item>
    </xsl:if>
    <xsl:if test="$data/majordomo/membership_counts/item">
      <xsl:variable name="sorted_mlist_list">
        <xsl:call-template name="ConvertToSortedNameValue">
          <xsl:with-param name="list" select="$data/majordomo/membership_counts/item"/>
          <xsl:with-param name="name_field" select="'name'"/>
          <xsl:with-param name="value_field" select="'membership_count'"/>
          <xsl:with-param name="sort_field" select="'membership_count'"/>
          <xsl:with-param name="datatype" select="'number'"/>
          <xsl:with-param name="order" select="'descending'"/>
        </xsl:call-template>
      </xsl:variable>
      <item name="top_mlists">
        <caption>
          <!--<xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'largest mailing lists'"/>
          </xsl:call-template>-->
          <xsl:value-of select="'largest mailing lists'"/>
        </caption>
        <content>
          <xsl:call-template name="NameValueTable">
            <xsl:with-param name="list" select="$sorted_mlist_list"/>
            <xsl:with-param name="id" select="'top_mlists'"/>
            <xsl:with-param name="limit" select="'6'"/>
            <xsl:with-param name="draw_link">
              concat('/siteadmin/services/majordomo/editMList?mlist=', name)
            </xsl:with-param>
          </xsl:call-template>
        </content>
      </item>
    </xsl:if>
  </xsl:variable>

  <xsl:variable name="toggleList">
    <xsl:call-template name="join_toggle_nodes">
      <xsl:with-param name="toggleElements" select="$toggleElements"/>
    </xsl:call-template>
  </xsl:variable>

  <table width="100%" border="0" cellspacing="0" cellpadding="0">
    <tr>
      <td colspan="2">
        <span class="dashboard-subhead-2">
          <!--<xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'Details:'"/>
          </xsl:call-template>-->
          <xsl:value-of select="epl:_('Details:')"/>
          <xsl:call-template name="DrawSelect">
            <xsl:with-param name="toggleList" select="$toggleList"/>
            <xsl:with-param name="name" select="'maildetails'"/>
            <xsl:with-param name="toggleElements" select="$toggleElements"/>
          </xsl:call-template>
        </span>
      </td>
    </tr>
  </table>

  <xsl:call-template name="DrawToggleElements">
    <xsl:with-param name="toggleElements">
      <xsl:copy-of select="$toggleElements"/>
    </xsl:with-param>
  </xsl:call-template>

  <script language="JavaScript">
     toggleDisplay('maildetails',  [<xsl:value-of select="$toggleList"/>]);
  </script>
</xsl:template>

<xsl:template name="AnalogDetailsTable">
  <xsl:param name="data"/>
  
</xsl:template>

<xsl:template name="WebalizerDetailsTable">
  <xsl:param name="data"/>
  <xsl:variable name="monthlyurl" select="'/siteadmin/services/webalizer/index.html'"/>
  <xsl:variable name="dailyurl" select="concat('/siteadmin/services/webalizer/usage_', $data/webalizer/current_yyyymm, '.html')"/>
  <xsl:variable name="current_month" select="$data/webalizer/current_yyyymm"/>

  <xsl:if test="$current_month!='None'">
    <table width="100%" border="0" cellspacing="0" cellpadding="0">
      <tr>
        <td colspan="2" >
          <span class="dashboard-subhead-2">
            <!--<xsl:call-template name="gettext">
              <xsl:with-param name="default" select="'Details'"/>
            </xsl:call-template>-->
            <xsl:value-of select="epl:_('Details')"/>
          </span>
        </td>
      </tr> 
      <tr> 
        <td width="1%"></td> 
        <td>
          <span>
            <a href="{$dailyurl}#HOURSTATS">
              <!--<xsl:call-template name="gettext">
                <xsl:with-param name="default" select="'Pages per Hour'"/>
              </xsl:call-template>-->
              <xsl:value-of select="epl:_('Pages per Hour')"/>
            </a>
          </span>
        </td>
      </tr>
      <tr>
        <td width="1%"></td>
        <td>
          <span>
            <a href="{$dailyurl}#DAYSTATS">
              <!--<xsl:call-template name="gettext">
                <xsl:with-param name="default" select="'Pages per Day'"/>
              </xsl:call-template>-->
              <xsl:value-of select="epl:_('Pages per Day')"/>
            </a>
          </span>
        </td>
      </tr> 
      <tr> 
        <td width="1%"></td> 
        <td>
          <span>
            <a href="{$monthlyurl}">
              <!--<xsl:call-template name="gettext">
                <xsl:with-param name="default" select="'Pages per Month'"/>
              </xsl:call-template>-->
              <xsl:value-of select="epl:_('Pages per Month')"/>
            </a>
          </span>
        </td> 
      </tr> 
      <tr> 
        <td width="10%"></td> 
        <td>
          <span>
            <a href="{$dailyurl}#HOURSTATS">
              <!--<xsl:call-template name="gettext">
                <xsl:with-param name="default" select="'Hits per Hour'"/>
              </xsl:call-template>-->
              <xsl:value-of select="epl:_('Hits per Hour')"/>
            </a>
          </span>
        </td> 
      </tr> 
      <tr> 
        <td width="1%"></td>
        <td>
          <span>
            <a href="{$dailyurl}#DAYSTATS">
              <!--<xsl:call-template name="gettext">
                <xsl:with-param name="default" select="'Hits per Day'"/>
              </xsl:call-template>-->
              <xsl:value-of select="epl:_('Hits per Day')"/>
            </a>
          </span>
        </td> 
      </tr> 
      <tr> 
        <td width="1%"></td> 
        <td>
          <span>
            <a href="{$monthlyurl}">
              <!--<xsl:call-template name="gettext">
                <xsl:with-param name="default" select="'Hits per Month'"/>
              </xsl:call-template>-->
              <xsl:value-of select="epl:_('Hits per Month')"/>
            </a>
          </span>
        </td>
      </tr> 
      <tr> 
        <td width="1%"></td> 
        <td>
          <span>
            <a href="{$dailyurl}#TOPSEARCH">
              <!--<xsl:call-template name="gettext">
                <xsl:with-param name="default" select="'Top Search Strings'"/>
              </xsl:call-template>-->
              <xsl:value-of select="epl:_('Top Search Strings')"/>
            </a>
          </span>
        </td>
      </tr> 
      <tr> 
        <td></td> 
        <td>
          <span>
            <a href="{$dailyurl}#TOPURLS">
              <!--<xsl:call-template name="gettext">
                <xsl:with-param name="default" select="'Top URLs'"/>
              </xsl:call-template>-->
              <xsl:value-of select="epl:_('Top URLs')"/>
            </a>
          </span>
        </td>
      </tr>
      <tr> 
        <td></td>
        <td>
          <span>
            <a href="{$dailyurl}#TOPENTRY">
              <!--<xsl:call-template name="gettext">
                <xsl:with-param name="default" select="'Top Entry Pages'"/>
              </xsl:call-template>-->
              <xsl:value-of select="epl:_('Top Entry Pages')"/>
            </a>
          </span>
        </td>
      </tr>
      <tr> 
        <td width="1%"></td>
        <td>
          <span>
            <a href="{$dailyurl}#TOPEXIT">
              <!--<xsl:call-template name="gettext">
                <xsl:with-param name="default" select="'Top Exit pages'"/>
              </xsl:call-template>-->
              <xsl:value-of select="epl:_('Top Exit pages')"/>
            </a>
          </span>
        </td>
      </tr> 
      <tr> 
        <td></td> 
        <td>
          <span>
            <a href="{$dailyurl}#TOPREFS">
              <!--<xsl:call-template name="gettext">
                <xsl:with-param name="default" select="'Top Referrers'"/>
              </xsl:call-template>-->
              <xsl:value-of select="epl:_('Top Referrers')"/>
            </a>
          </span>
        </td> 
      </tr>
      <tr> 
        <td width="1%"></td> 
        <td>
          <span>
            <a href="{$dailyurl}#TOPSITES">
              <!--<xsl:call-template name="gettext">
                <xsl:with-param name="default" select="'Top Sites by Visits'"/>
              </xsl:call-template>-->
              <xsl:value-of select="epl:_('Top Sites by Visits')"/>
            </a>
          </span>
        </td>
      </tr> 
      <tr> 
        <td width="1%"></td> 
        <td>
          <span>
            <a href="{$dailyurl}#TOPAGENTS">
              <!--<xsl:call-template name="gettext">
                <xsl:with-param name="default" select="'Top Browsers'"/>
              </xsl:call-template>-->
              <xsl:value-of select="epl:_('Top Browsers')"/>
            </a>
          </span>
        </td> 
      </tr> 
      <tr> 
        <td></td> 
        <td>
          <span class="right-align">
            <a href="{$dailyurl}">
              <!--<xsl:call-template name="gettext">
                <xsl:with-param name="default" select="'more details...'"/>
              </xsl:call-template>-->
              <xsl:value-of select="epl:_('more details...')"/>
            </a>
          </span>
        </td> 
      </tr>
    </table>
  </xsl:if>
</xsl:template>

<xsl:template name="WebGraphRows">
  <xsl:param name="webstatsnode"/>

  <!-- DAYS -->
  <xsl:variable name="sorted_days">
    <xsl:call-template name="ConvertToSortedNameValue">
      <xsl:with-param name="list" select="exsl:node-set($webstatsnode)/last_7_days_hits/item"/>
      <xsl:with-param name="name_field" select="'day'"/>
      <xsl:with-param name="value_field" select="'hits'"/>
      <xsl:with-param name="sort_field" select="'epoch'"/>
      <xsl:with-param name="datatype" select="'number'"/>
      <xsl:with-param name="order" select="'ascending'"/>
    </xsl:call-template>
  </xsl:variable>
  <xsl:variable name="joined_name_days">
    <xsl:for-each select="exsl:node-set($sorted_days)/itemlist/item">
      <token>
        <xsl:call-template name="search-and-replace">
          <xsl:with-param name="input" select="name"/>
          <xsl:with-param name="search-string" select="'/'"/>
          <xsl:with-param name="replace-string" select="'%2f'"/>
        </xsl:call-template>
      </token>
      <xsl:if test="position() != last()">
        <token>,</token>
      </xsl:if>
    </xsl:for-each>
  </xsl:variable>
  <xsl:variable name="joined_value_days">
    <xsl:for-each select="exsl:node-set($sorted_days)/itemlist/item">
      <token><xsl:value-of select="value"/></token>
      <xsl:if test="position() != last()">
        <token>,</token>
      </xsl:if>
    </xsl:for-each>
  </xsl:variable>

  <!-- MONTHS -->
  <xsl:variable name="sorted_months">
    <xsl:call-template name="ConvertToSortedNameValue">
      <xsl:with-param name="list" select="exsl:node-set($webstatsnode)/last_7_months_hits/item"/>
      <xsl:with-param name="name_field" select="'month'"/>
      <xsl:with-param name="value_field" select="'hits'"/>
      <xsl:with-param name="sort_field" select="'epoch'"/>
      <xsl:with-param name="datatype" select="'number'"/>
      <xsl:with-param name="order" select="'ascending'"/>
    </xsl:call-template>
  </xsl:variable>
  <xsl:variable name="joined_name_months">
    <xsl:for-each select="exsl:node-set($sorted_months)/itemlist/item">
      <token>
        <xsl:call-template name="search-and-replace">
          <xsl:with-param name="input" select="name"/>
          <xsl:with-param name="search-string" select="'/'"/>
          <xsl:with-param name="replace-string" select="'%2f'"/>
        </xsl:call-template>
      </token>
      <xsl:if test="position() != last()">
        <token>,</token>
      </xsl:if>
    </xsl:for-each>
  </xsl:variable>
  <xsl:variable name="joined_value_months">
    <xsl:for-each select="exsl:node-set($sorted_months)/itemlist/item">
      <token><xsl:value-of select="value"/></token>
      <xsl:if test="position() != last()">
        <token>,</token>
      </xsl:if>
    </xsl:for-each>
  </xsl:variable>

  <xsl:variable name="toggleElements">
    <item name="last_7_days" selected="selected">
      <caption>
        <!--<xsl:call-template name="gettext">
          <xsl:with-param name="default" select="'days'"/>
        </xsl:call-template>-->
        <xsl:value-of select="epl:_('days')"/>
      </caption>
      <content>
        <xsl:choose>
          <xsl:when test="$joined_name_days = ''">
            <center>
              <!--<xsl:call-template name="gettext">
                <xsl:with-param name="default" select="'Not Available'"/>
              </xsl:call-template>-->
              <xsl:value-of select="epl:_('Not Available')"/>
            </center>
          </xsl:when>
          <xsl:otherwise>
            <center>
             <img src="/siteadmin/services/{name(exsl:node-set($webstatsnode))}/view_webgraph?names_values={$joined_name_days}-_-{$joined_value_days}"/>              
    </center>
          </xsl:otherwise>
        </xsl:choose>
      </content>
    </item>
    <item name="last_7_months">
      <caption>
        <!--<xsl:call-template name="gettext">
          <xsl:with-param name="default" select="'months'"/>
        </xsl:call-template>-->
        <xsl:value-of select="epl:_('months')"/>
      </caption>
      <content>
        <xsl:choose>
          <xsl:when test="$joined_name_months = ''">
            <center>
              <!--<xsl:call-template name="gettext">
                <xsl:with-param name="default" select="'Not Available'"/>
              </xsl:call-template>-->
              <xsl:value-of select="epl:_('Not Available')"/>
            </center>
          </xsl:when>
          <xsl:otherwise>
            <center>
              <img src="/siteadmin/services/{name(exsl:node-set($webstatsnode))}/view_webgraph?names_values={$joined_name_months}-_-{$joined_value_months}"/>
            </center>
          </xsl:otherwise>
        </xsl:choose>
      </content>
    </item>
  </xsl:variable>

  <xsl:variable name="toggleList">
    <xsl:call-template name="join_toggle_nodes">
      <xsl:with-param name="toggleElements" select="$toggleElements"/>
    </xsl:call-template>
  </xsl:variable>

  <tr>
    <xsl:choose>
        <xsl:when test="$joined_name_months=''">
            <td colspan="2" align="center">
              <center><xsl:value-of select="epl:_('Not Available')"/></center>
            </td>
        </xsl:when>
        <xsl:otherwise>
            <td>
              <span>
                <!--<xsl:call-template name="gettext">
                  <xsl:with-param name="default" select="'Past 7 :'"/>
                </xsl:call-template>-->
                <xsl:value-of select="epl:_('Past 7 :')"/>
              </span>
            </td>
            <td>
              <xsl:call-template name="DrawSelect">
                <xsl:with-param name="toggleList" select="$toggleList"/>
                <xsl:with-param name="name" select="'daymonth'"/>
                <xsl:with-param name="toggleElements" select="$toggleElements"/>
              </xsl:call-template>
            </td>
        </xsl:otherwise>
    </xsl:choose>
  </tr>
  <tr>
    <td colspan="2">
      <xsl:call-template name="DrawToggleElements">
        <xsl:with-param name="toggleElements">
          <xsl:copy-of select="$toggleElements"/>
        </xsl:with-param>
      </xsl:call-template>
    </td>
  </tr> 
  <xsl:if test="$joined_name_months!=''">
    <script language="JavaScript">
      toggleDisplay('daymonth', [<xsl:value-of select="$toggleList"/>]);
    </script>
  </xsl:if>

</xsl:template>

<xsl:template name="UniquePageHitsTable">
  <xsl:param name="webstatsnode"/>
  <table width="100%" border="0" cellspacing="0" cellpadding="0">
    <tr>
      <td colspan="2">
        <span class="dashboard-subhead-2">
          <!--<xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'Unique Page Hits'"/>
          </xsl:call-template>-->
          <xsl:value-of select="epl:_('Unique Page Hits')"/>
        </span>
      </td>
    </tr>
    <tr> 
      <td>
        <span>
          <!--<xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'Monthly Avg.:'"/>
          </xsl:call-template>-->
          <xsl:value-of select="epl:_('Monthly Avg.:')"/>
        </span>
      </td>
      <td class="right-align">
        <span><xsl:value-of select="$webstatsnode/monthly_avg_hits"/></span>
      </td> 
    </tr> 
    <tr> 
      <td >
        <span>
          <!--<xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'Last Month:'"/>
          </xsl:call-template>-->
          <xsl:value-of select="epl:_('Last Month:')"/>
        </span>
      </td>
      <td class="right-align">
        <span><xsl:value-of select="$webstatsnode/last_month_total_hits"/></span>
      </td> 
    </tr> 
    <tr> 
      <td>
        <span>
          <strong>
            <!--<xsl:call-template name="gettext">
              <xsl:with-param name="default" select="'This Month:'"/>
            </xsl:call-template>-->
            <xsl:value-of select="epl:_('This Month:')"/>
          </strong>
        </span>
      </td> 
      <td class="right-align">
        <span><xsl:value-of select="$webstatsnode/this_month_total_hits"/></span>
      </td> 
    </tr> 
    <tr> 
      <td>&#160;</td> 
      <td>&#160;</td> 
    </tr>
    <tr> 
      <td colspan="2"><hr/></td>
    </tr>
    <xsl:call-template name="WebGraphRows">
      <xsl:with-param name="webstatsnode" select="$webstatsnode"/>
    </xsl:call-template>
  </table>

</xsl:template>

<xsl:template name="MailStatsTable">
  <xsl:param name="data"/>
  <table width="100%" border="0" cellspacing="0" cellpadding="0">
    <tr>
      <td>
        <span class="dashboard-subhead-2">
          <!--<xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'Users (Mailboxes):'"/>
          </xsl:call-template>-->
          <xsl:value-of select="epl:_('Users (Mailboxes):')"/>
        </span>
      </td>
      <td><span class="right-align"><xsl:value-of select="$data/sendmail/user_count - 1"/>/<xsl:value-of select="$data/sendmail/user_max"/></span></td>
    </tr>
    <tr>
      <td>
        <span class="dashboard-subhead-2">
          <!--<xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'Disk Used by Mail :'"/>
          </xsl:call-template>-->
          <xsl:value-of select="epl:_('Disk Used by Mail :')"/>
        </span>
      </td>
      <td>
        <span class="right-align">
          <xsl:value-of select="format-number(func:B_to_MB($data/sendmail/total_mailbox_size), '0')"/>&#160;
          <!--<xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'MB'"/>
          </xsl:call-template>-->
          <xsl:value-of select="epl:_('MB')"/>
        </span>
      </td>
    </tr>
    <tr>
      <td>
        <span class="dashboard-subhead-2">
          <!--<xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'Mails In Queue:'"/>
          </xsl:call-template>-->
          <xsl:value-of select="epl:_('Mails In Queue:')"/>
        </span>
      </td> 
      <td><span class="right-align"><xsl:value-of select="$data/sendmail/queue_total_mails"/></span></td>
    </tr>
    <tr>
      <td>
        <span class="dashboard-subhead-2">
          <!--<xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'Mail Queue Size:'"/>
          </xsl:call-template>-->
          <xsl:value-of select="epl:_('Mail Queue Size:')"/>
        </span>
      </td>
      <td>
        <span class="right-align">
          <xsl:value-of select="format-number(func:B_to_MB($data/sendmail/queue_size), '0')"/>&#160;
          <!--<xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'MB'"/>
          </xsl:call-template>-->
          <xsl:value-of select="epl:_('MB')"/>
        </span>
      </td>
    </tr>
    <tr>
      <td>
        <span class="dashboard-subhead-2">
          <!--<xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'Aliases:'"/>
          </xsl:call-template>-->
          <xsl:value-of select="epl:_('Aliases:')"/>
        </span>
      </td> 
      <td><span class="right-align"><xsl:value-of select="$data/sendmail/total_aliases"/></span></td>
    </tr>
    <tr>
      <td>
        <span class="dashboard-subhead-2">
          <!--<xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'Responders:'"/>
          </xsl:call-template>-->
          <xsl:value-of select="epl:_('Responders:')"/>
        </span>
      </td>
      <td><span class="right-align"><xsl:value-of select="$data/sendmail/total_responders"/></span></td>
    </tr>
    <xsl:if test="$data/majordomo">
      <tr>
        <td>
          <span class="dashboard-subhead-2">
            <!--<xsl:call-template name="gettext">
              <xsl:with-param name="default" select="'Mailing Lists:'"/>
            </xsl:call-template>-->
            <xsl:value-of select="epl:_('Mailing Lists:')"/>
          </span>
        </td>
        <td><span class="right-align"><xsl:value-of select="$data/majordomo/total_mlists"/></span></td>
      </tr>
    </xsl:if>
  </table>
</xsl:template>

<xsl:template name="ASPDivs">
  <xsl:param name="asps"/>
  <xsl:param name="category"/>

  <xsl:if test="count($asps/item[category = $category]) > 0">
    <div>
      <xsl:for-each select="$asps/item[category = $category]">
        <div> 
          <div><xsl:value-of select="sa_title"/> <img src="/static/images/new.gif"/></div>
          <div ><xsl:value-of select="sa_desc"/></div>
          <div>
            <!-- put spaces if Manage or Add missing -->
            <xsl:choose>
                <xsl:when test="manage">
                  <a href="{manage}" target="_new">
                    <!--<xsl:call-template name="gettext">
                      <xsl:with-param name="default" select="'Manage'"/>
                    </xsl:call-template>-->
                    <xsl:value-of select="epl:_('Manage')"/>
                  </a>
                </xsl:when>
                <xsl:otherwise>
                    &#160;&#160;&#160;&#160;&#160;&#160;
                </xsl:otherwise>
            </xsl:choose>
            &#160;&#160;&#160;&#160;
            <xsl:choose>
                <xsl:when test="add">
                  <a href="{add}" target="_new">
                    <!--<xsl:call-template name="gettext">
                      <xsl:with-param name="default" select="'Add'"/>
                    </xsl:call-template>-->
                    <xsl:value-of select="epl:_('Add')"/>
                  </a>
                </xsl:when>
                <xsl:otherwise>
                    &#160;&#160;&#160;&#160;&#160;&#160;
                </xsl:otherwise>
            </xsl:choose>
          </div>
        </div>
      </xsl:for-each>
    </div>
  </xsl:if>

</xsl:template>

<xsl:template name="ASPDivsHorizontal">
  <xsl:param name="asps"/>
  <xsl:param name="category"/>

  <xsl:if test="count($asps/item[category = $category]) > 0">
        <table width="100%" border="1">
        <tr>
      <xsl:for-each select="$asps/item[category = $category]">
        <td width="25%" valign="top">
          <div>
            <div> 
              <div><xsl:value-of select="sa_title"/> <img src="/static/images/new.gif"/></div>
                <div ><xsl:value-of select="sa_desc"/></div>
                <!--short description and we get some damn line in there-->
                  <div>
                    <!-- put spaces if Manage or Add missing -->
                    <xsl:choose>
                      <xsl:when test="manage">
                        <a href="{manage}" target="_new">
                          <!--<xsl:call-template name="gettext">
                            <xsl:with-param name="default" select="'Manage'"/>
                          </xsl:call-template>-->
                          <xsl:value-of select="epl:_('Manage')"/>
                        </a>
                      </xsl:when>
                      <xsl:otherwise>
                        &#160;&#160;&#160;&#160;&#160;&#160;
                      </xsl:otherwise>
                    </xsl:choose>
                      &#160;&#160;&#160;&#160;
                    <xsl:choose>
                      <xsl:when test="add">
                        <a href="{add}" target="_new">
                          <!--<xsl:call-template name="gettext">
                            <xsl:with-param name="default" select="'Add'"/>
                          </xsl:call-template>-->
                          <xsl:value-of select="epl:_('Add')"/>
                        </a>
                      </xsl:when>
                      <xsl:otherwise>
                        &#160;&#160;&#160;&#160;&#160;&#160;
                      </xsl:otherwise>
                    </xsl:choose>
                  </div>
            </div>
          </div>
        </td>
      </xsl:for-each>
        </tr>
        </table>
  </xsl:if>

</xsl:template>


<xsl:template name="WebFullPane">
  <xsl:param name="data"/>
  <xsl:param name="root"/>
  <xsl:variable name="caption">
    <!--<xsl:call-template name="gettext">
      <xsl:with-param name="default" select="'build, manage, and enhance my web site'"/>
    </xsl:call-template>-->
    <xsl:value-of select="epl:_('build, manage, and enhance my web site')"/>
  </xsl:variable>
  <xsl:variable name="headerRow">
    <xsl:call-template name="FullPaneHeaderRow">
      <xsl:with-param name="icon" select="'/static/images/site-family.gif'"/>
      <xsl:with-param name="caption">
        <!--<xsl:call-template name="gettext">
          <xsl:with-param name="default" select="'My Web Site'"/>
        </xsl:call-template>-->
        <xsl:value-of select="epl:_('My Web Site')"/>
      </xsl:with-param>
      <xsl:with-param name="desc" select="$caption"/>
      <xsl:with-param name="columns" select="'4'"/>
    </xsl:call-template>
  </xsl:variable>

  <xsl:variable name="uniquePageHitsTable">
    <xsl:choose>
      <xsl:when test="$data/webalizer">
        <xsl:call-template name="UniquePageHitsTable">
          <xsl:with-param name="webstatsnode" select="$data/webalizer"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:when test="$data/analog">
        <xsl:call-template name="UniquePageHitsTable">
          <xsl:with-param name="webstatsnode" select="$data/analog"/>
        </xsl:call-template>
      </xsl:when>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name="detailsTables">
    <xsl:call-template name="WebalizerDetailsTable">
      <xsl:with-param name="data" select="$data"/>
    </xsl:call-template>
  </xsl:variable>

  <xsl:variable name="aspDivs">
  <xsl:choose>
  <xsl:when test="$data/analog or $data/webalizer">
      <!--<xsl:variable name="aspDivs">-->
        <xsl:call-template name="ASPDivs">
          <xsl:with-param name="asps" select="$root/services/aspmgr/site_asps"/>
          <xsl:with-param name="category" select="'web'"/>
        </xsl:call-template>
      <!--</xsl:variable>-->
  </xsl:when>
  <xsl:otherwise>
      <!--<xsl:variable name="aspDivs">-->
        <xsl:call-template name="ASPDivsHorizontal">
          <xsl:with-param name="asps" select="$root/services/aspmgr/site_asps"/>
          <xsl:with-param name="category" select="'web'"/>
        </xsl:call-template>
      <!--</xsl:variable>-->
  </xsl:otherwise>
  </xsl:choose>
  </xsl:variable>

  <xsl:choose>
  <xsl:when test="$data/analog or $data/webalizer">
  <table class="isp-dashboard" border="0" cellspacing="0" cellpadding="0">  
          <xsl:copy-of select="$headerRow"/>
   	      <tr>
			<td>
				<table width="100%" height="100%" cellspacing="0">
					<tr>
					  <td class="isp-dashboard-section-top-l-without-title"/>
					  <td class="isp-dashboard-section-top-without-title"/>
					  <td class="isp-dashboard-section-top-r-without-title"/>
					</tr>

					<tr>
					  <td class="isp-dashboard-section-left"/>
					  <td valign="center" class="isp-dashboard-section-contents">
					  
							<!--  C O N T E N T S  -->
							  <table width="100%" cellpadding="0" cellspacing="2" border="0">
								<tr>
								  <td width="48%" valign="top">
									<xsl:copy-of select="$uniquePageHitsTable"/>
								  </td>
								  <td width="4%"></td> 
								  <td valign="top">
									<xsl:if test="$data/webalizer">
									  <xsl:call-template name="WebalizerDetailsTable">
										<xsl:with-param name="data" select="$data"/>
									  </xsl:call-template>
									</xsl:if>
								  </td>
								</tr>
							  </table>
							<!--  C O N T E N T S   E N D S -->
						</td>	
						<td class="isp-dashboard-section-right"/>
			        </tr>
			        <tr>
			          <td class="isp-dashboard-section-bottom-l"/>
				      <td class="isp-dashboard-section-bottom"/>
			          <td class="isp-dashboard-section-bottom-r"/>
			        </tr>
		      </table>
            </td>
<!--            <xsl:if test="$aspDivs != ''">
              <td valign="top">
                <xsl:copy-of select="$aspDivs"/>
              </td>
            </xsl:if>
-->
          </tr>
        </table>
  </xsl:when>
  <!-- Draw Horizontal Boxes -->
  <xsl:otherwise test="$data/analog or $data/webalizer">
	  <table class="isp-dashboard" border="0" cellspacing="0" cellpadding="0">  
          <xsl:copy-of select="$headerRow"/>
		  <tr>
			<td>
				<table width="100%" height="100%" cellspacing="0">
					<tr>
					  <td class="isp-dashboard-section-top-l-without-title"/>
					  <td class="isp-dashboard-section-top-without-title"/>
					  <td class="isp-dashboard-section-top-r-without-title"/>
					</tr>

					<tr>
					  <td class="isp-dashboard-section-left"/>
					  <td valign="center" class="isp-dashboard-section-contents">
					  
						<!--  C O N T E N T S  -->
			            <xsl:if test="$aspDivs != ''">
				              <xsl:copy-of select="$aspDivs"/>
			            </xsl:if>
						<!--  C O N T E N T S   E N D S -->
						</td>	
						<td class="isp-dashboard-section-right"/>
			        </tr>
			        <tr>
			          <td class="isp-dashboard-section-bottom-l"/>
				      <td class="isp-dashboard-section-bottom"/>
			          <td class="isp-dashboard-section-bottom-r"/>
			        </tr>
		      </table>
            </td>
          </tr>
        </table>
  </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="MailFullPane">
  <xsl:param name="data"/>
  <xsl:param name="root"/>

  <xsl:variable name="caption">
    <!--<xsl:call-template name="gettext">
      <xsl:with-param name="default" select='"manage and monitor my site&#39;s user &amp; email resources"'/>
    </xsl:call-template>-->
    <xsl:value-of select='epl:_("manage and monitor my site&#39;s user &amp; email resources")'/>
  </xsl:variable>
  <xsl:variable name="headerRow">
    <xsl:call-template name="FullPaneHeaderRow">
      <xsl:with-param name="icon" select="'/static/images/site-user-mail.gif'"/>
      <xsl:with-param name="caption">
        <!--<xsl:call-template name="gettext">
          <xsl:with-param name="default" select="'Users &amp; Mailboxes'"/>
        </xsl:call-template>-->
        <xsl:value-of select="epl:_('Users &amp; Mailboxes')"/>
      </xsl:with-param>
      <xsl:with-param name="desc" select="$caption"/>
      <xsl:with-param name="columns" select="'2'"/>
    </xsl:call-template>
  </xsl:variable>

    <xsl:variable name="statsTable">
      <xsl:call-template name="MailStatsTable">
        <xsl:with-param name="data" select="$data"/>
      </xsl:call-template>
    </xsl:variable>
  
    <xsl:variable name="detailsTables">
      <xsl:call-template name="MailDetailsTables">
        <xsl:with-param name="data" select="$data"/>
      </xsl:call-template>
    </xsl:variable>

  <xsl:variable name="aspDivs">
    <xsl:call-template name="ASPDivs">
      <xsl:with-param name="asps" select="$root/services/aspmgr/site_asps"/>
      <xsl:with-param name="category" select="'mail'"/>
    </xsl:call-template>
  </xsl:variable>

 <table class="isp-dashboard" border="0" cellspacing="0" cellpadding="0"> 
          <xsl:copy-of select="$headerRow"/>
           <tr>
			<td>
				<table width="100%" height="100%" cellspacing="0">
					<tr>
					  <td class="isp-dashboard-section-top-l-without-title"/>
					  <td class="isp-dashboard-section-top-without-title"/>
					  <td class="isp-dashboard-section-top-r-without-title"/>
					</tr>

					<tr>
					  <td class="isp-dashboard-section-left"/>
					  <td valign="center" class="isp-dashboard-section-contents">
					  
						<!--  C O N T E N T S  -->
						  <table width="100%" cellpadding="0" cellspacing="2" border="0">
							<xsl:if test="$data/sendmail">
							  <tr>
								<td width="48%">
								  <xsl:copy-of select="$statsTable"/>
								</td>
								<td width="4%"> </td> 
								<td>
								  <xsl:copy-of select="$detailsTables"/>
								</td>
							  </tr>
							</xsl:if>
						  </table>

						<xsl:if test="$aspDivs != ''">
<!--						  <td valign="top">-->
							<xsl:copy-of select="$aspDivs"/>
<!--						  </td>-->
						</xsl:if>
					<!--  C O N T E N T S   E N D S -->
					
						</td>	
						<td class="isp-dashboard-section-right"/>
			        </tr>
			        <tr>
			          <td class="isp-dashboard-section-bottom-l"/>
				      <td class="isp-dashboard-section-bottom"/>
			          <td class="isp-dashboard-section-bottom-r"/>
			        </tr>
		      </table>
            </td>
          </tr>
        </table>	
</xsl:template>

<xsl:template name="ProgressBarTable">
  <xsl:param name="current"/>
  <xsl:param name="total"/>
  <xsl:param name="bar_width" select="'140'"/>
  <xsl:variable name="current_width">
    <xsl:choose>
      <xsl:when test="$current &gt;= $total">
        <xsl:value-of select="$bar_width"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="ceiling(($current div $total) * $bar_width)"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  <xsl:variable name="total_width" select="$bar_width - $current_width"/>
  <table cellSpacing="0" cellPadding="0" width="{$bar_width}" style="width:{$bar_width};" border="0" class="progress-bar"> 
    <tr> 
      <td class="barOn">
        <xsl:choose>
          <xsl:when test="$current_width = $bar_width">
            <img height="11" src="/static/images/progressbar_red.gif" width="{$current_width}" border="0"/>
          </xsl:when>
          <xsl:when test="$current_width &gt;= 0.9 * $bar_width">
            <img height="11" src="/static/images/progressbar_yellow.gif" width="{$current_width}" border="0"/>
          </xsl:when>
          <xsl:otherwise>
            <img height="11" src="/static/images/progressbar_fill.gif" width="{$current_width}" border="0"/>
          </xsl:otherwise>
        </xsl:choose>
      </td>
      <td class="barOff">
        <img height="11" src="/static/images/progressbar_empty.gif" width="{$total_width}" border="0"/>
      </td> 
      <xsl:if test="$current_width &gt;= 0.9 * $bar_width">
        <td>
          &#160;&#160;<img src="/static/images/small-warning.gif"/>
        </td>
      </xsl:if>
    </tr>
  </table>
</xsl:template>


<xsl:template name="UsageBarsTable">
  <xsl:param name="data"/>
  
  <table width="100%" border="0" cellspacing="0" cellpadding="0">
    <xsl:if test="$data/users">
      <tr>
        <td width="30%">
          <span class="dashboard-subhead-2">
            <!--<xsl:call-template name="gettext">
              <xsl:with-param name="default" select="'Users:'"/>
            </xsl:call-template>-->
            <xsl:value-of select="epl:_('Users:')"/>
          </span>
        </td>
        <td>
          <span class="right-align"><xsl:value-of select="$data/users/user_count - 1"/>/<xsl:value-of select="$data/users/user_max"/></span>
          <span>
            <xsl:call-template name="ProgressBarTable">
              <xsl:with-param name="current" select="$data/users/user_count - 1"/>
              <xsl:with-param name="total" select="$data/users/user_max"/>
            </xsl:call-template>
          </span>
        </td> 
      </tr>
    </xsl:if>
    <xsl:if test="$data/subdomain">
      <tr>
        <td>
          <span class="dashboard-subhead-2">
            <!--<xsl:call-template name="gettext">
              <xsl:with-param name="default" select="'Subdomains:'"/>
            </xsl:call-template>-->
            <xsl:value-of select="epl:_('Subdomains:')"/>
          </span>
        </td>
        <td>
    <xsl:choose>
    <xsl:when test="$data/subdomain/subdomain_max=-1">
          <span class="right-align"><xsl:value-of select="$data/subdomain/subdomain_count"/>/<xsl:value-of select="epl:_('Unlimited')"/></span>
    </xsl:when>
    <xsl:otherwise>
          <span class="right-align"><xsl:value-of select="$data/subdomain/subdomain_count"/>/<xsl:value-of select="$data/subdomain/subdomain_max"/></span>
          <span>
            <xsl:call-template name="ProgressBarTable">
              <xsl:with-param name="current" select="$data/subdomain/subdomain_count"/>
              <xsl:with-param name="total" select="$data/subdomain/subdomain_max"/>
            </xsl:call-template>
          </span>
    </xsl:otherwise>
    </xsl:choose>
        </td>
      </tr>
    </xsl:if>
    <xsl:if test="$data/mysql">
      <tr>
        <td>
          <span class="dashboard-subhead-2">
            <!--<xsl:call-template name="gettext">
              <xsl:with-param name="default" select="'Databases:'"/>
            </xsl:call-template>-->
            <xsl:value-of select="epl:_('Databases:')"/>
          </span>
        </td>
        <td>
          <span class="right-align"><xsl:value-of select="$data/mysql/db_count"/>/<xsl:value-of select="$data/mysql/db_max"/></span>
          <span>
            <xsl:call-template name="ProgressBarTable">
              <xsl:with-param name="current" select="$data/mysql/db_count"/>
              <xsl:with-param name="total" select="$data/mysql/db_max"/>
            </xsl:call-template>
          </span>
        </td>
      </tr>
    </xsl:if>
  </table>
</xsl:template>

<xsl:template name="LoginBackupTable">
  <xsl:param name="data"/>
  <table width="100%" border="0" cellspacing="0" cellpadding="0">
    <tr>
      <td>
        <span class="dashboard-subhead-2">
          <!--<xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'Last Log In:'"/>
          </xsl:call-template>-->
          <xsl:value-of select="epl:_('Last Log In:')"/>
        </span>
      </td>
      <td>
        <span><xsl:value-of select="$data/siteinfo/site_last_login"/></span>
      </td>
    </tr>
    <xsl:if test="$data/vhbackup">
      <tr>
        <td>
          <span class="dashboard-subhead-2">
            <!--<xsl:call-template name="gettext">
              <xsl:with-param name="default" select="'Last Export Completed:'"/>
            </xsl:call-template>-->
            <xsl:value-of select="epl:_('Last Export Completed:')"/>
          </span>
        </td>
        <td>
          <span>
            <xsl:choose>
              <xsl:when test="$data/vhbackup/last_completed">
                <xsl:value-of select="$data/vhbackup/last_completed"/>
              </xsl:when>
              <xsl:otherwise>
                <!--<xsl:call-template name="gettext">
                  <xsl:with-param name="default" select="'Unavailable'"/>
                </xsl:call-template>-->
                <xsl:value-of select="epl:_('Unavailable')"/>
              </xsl:otherwise>
            </xsl:choose>
          </span>
        </td>
      </tr>
      <tr>
        <td>
          <span class="dashboard-subhead-2">
            <!--<xsl:call-template name="gettext">
              <xsl:with-param name="default" select="'Next Scheduled Export:'"/>
            </xsl:call-template>-->
            <xsl:value-of select="epl:_('Next Scheduled Export:')"/>
          </span></td> 
          <td>
            <span><xsl:value-of select="$data/vhbackup/next_scheduled"/></span>
          </td> 
        </tr>
        <tr> 
        <td></td>
        <td>
          <span class="right-align">
            <a href="/webhost/services/virtualhosting/siteadmin/services/vhbackup/form_stream_bk">
              <!--<xsl:call-template name="gettext">
                <xsl:with-param name="default" select="'Start Export Now'"/>
              </xsl:call-template>-->
              <xsl:value-of select="epl:_('Start Export Now')"/>
            </a>
          </span>
        </td>
      </tr>
    </xsl:if>

  </table>
</xsl:template>

<xsl:template name="GeneralDiv">
  <xsl:param name="data"/>
  <div class="dashboard-subhead-1">
    <!--<xsl:call-template name="gettext">
      <xsl:with-param name="default" select="'General'"/>
    </xsl:call-template>-->
    <xsl:value-of select="epl:_('General')"/>
  </div>
  <div>
    <table width="100%" cellpadding="0" cellspacing="2" border="0">
      <tr>
        <td width="48%">
          <xsl:call-template name="LoginBackupTable">
            <xsl:with-param name="data" select="$data"/>
          </xsl:call-template>
        </td>
        <td width="4%"> </td> 
        <td>
          <xsl:call-template name="UsageBarsTable">
            <xsl:with-param name="data" select="$data"/>
          </xsl:call-template>
        </td>
      </tr>
    </table>
  </div>
</xsl:template>

<xsl:template name="LimitLastThisTable">
  <!-- used to display the bandwidth table -->
  <xsl:param name="data"/>
  <xsl:variable name="ispro" select="epl:isPro()"/>
  <xsl:if test="$ispro = 'True'">
  <xsl:variable name="total_value" select="$data/bandwidth/limit"/>
  <xsl:variable name="used_value" select="$data/bandwidth/this_month_usage"/>
  <xsl:variable name="last_month" select="$data/bandwidth/last_month_usage"/>
  <table width="100%" border="0" cellspacing="0" cellpadding="0">
    <!-- no bar graph when total_value is zero -->
    <!-- Avoid divide by Zero errors -->
    <xsl:choose>
        <xsl:when test="$total_value!=0">
            <tr>
                <td width="69%">
                    <xsl:call-template name="ProgressBarTable">
                    <xsl:with-param name="current" select="$used_value"/>
                    <xsl:with-param name="total" select="$total_value"/>
                    <xsl:with-param name="bar_width" select="'190'"/>
                    </xsl:call-template>
                </td>
                <td width="31%">
                    <span class="right-align"><xsl:value-of select="format-number(($used_value div $total_value) * 100, '0')"/>%</span>
                </td>
            </tr>
        </xsl:when>
    </xsl:choose>
    <tr>
      <td>
        <span class="dashboard-subhead-2">
          <!--<xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'Monthly Limit:'"/>
          </xsl:call-template>-->
          <xsl:value-of select="epl:_('Monthly Limit:')"/>
        </span>
      </td>
      <!-- If total_value is Zero show Monthly Limit as Unlimited -->
      <xsl:choose>
        <xsl:when test="$total_value!=0">
            <td>
                <span class="right-align"><xsl:value-of select="format-number(func:B_to_MB($total_value), '0.0')"/></span>
            </td>
        </xsl:when>
        <xsl:when test="$total_value=0">
            <td>
                <span class="right-align">Unlimited</span>
            </td>
        </xsl:when>
      </xsl:choose>
    </tr> 
    <tr> 
      <td>
        <span>
          <!--<xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'Last Month:'"/>
          </xsl:call-template>-->
          <xsl:value-of select="epl:_('Last Month:')"/>
        </span>
      </td> 
      <td>
        <span class="right-align"><xsl:value-of select="format-number(func:B_to_MB($last_month), '0.0')"/></span>
      </td>
    </tr>
    <tr> 
      <td>
        <span>
          <strong>
            <!--<xsl:call-template name="gettext">
              <xsl:with-param name="default" select="'This Month:'"/>
            </xsl:call-template>-->
            <xsl:value-of select="epl:_('This Month:')"/>
          </strong>
        </span>
      </td> 
      <td>
        <span class="right-align"><xsl:value-of select="format-number(func:B_to_MB($used_value), '0.0')"/></span>
      </td>
    </tr>
  </table>
</xsl:if>
</xsl:template>


<xsl:template name="ValidateAvailableSpace">
  <!-- If available space is less than zero, display 0.0 instead of negative value -->
  <xsl:param name="avail_space"/>
      <xsl:if test="$avail_space &lt;= 0.0">
          <span class="right-align">0.0</span>
      </xsl:if>
      <xsl:if test="$avail_space &gt; 0.0">
          <span class="right-align"><xsl:value-of select="$avail_space"/></span>
      </xsl:if>
</xsl:template>


<xsl:template name="TotalUsedAvailTable">
  <xsl:param name="total_caption"/>
  <xsl:param name="used_caption"/>
  <xsl:param name="avail_caption"/>
  <xsl:param name="total_value"/>
  <xsl:param name="used_value"/>
  <xsl:param name="data"/>

  <table width="100%" border="0" cellspacing="0" cellpadding="0">
    <xsl:if test="$total_value!=0">
    <tr>
      <td width="69%">
        <xsl:call-template name="ProgressBarTable">
          <xsl:with-param name="current" select="$used_value"/>
          <xsl:with-param name="total" select="$total_value"/>
          <xsl:with-param name="bar_width" select="'190'"/>
        </xsl:call-template>
      </td>
      <td width="31%">
        <span class="right-align"><xsl:value-of select="format-number(($used_value div $total_value) * 100, '0')"/>%</span>
      </td>
    </tr>
    </xsl:if>
    <tr>
      <td>
        <span class="dashboard-subhead-2"><xsl:value-of select="$total_caption"/>:</span>
      </td>
      <td>
        <xsl:if test="$total_value!=0">
          <span class="right-align"><xsl:value-of select="format-number(func:B_to_MB($total_value), '0.0')"/></span>
        </xsl:if>  
        <xsl:if test="$total_value=0">
          <xsl:value-of select="epl:_('Unlimited')"/>
        </xsl:if>
      </td>
    </tr> 
    <tr> 
      <td>
        <span class="dashboard-subhead-2"><xsl:value-of select="$used_caption"/>:</span>
      </td> 
      <td>
        <span class="right-align"><xsl:value-of select="format-number(func:B_to_MB($used_value), '0.0')"/></span>
      </td>
    </tr>
    <tr> 
      <td>
        <span class="dashboard-subhead-2"><strong><xsl:value-of select="$avail_caption"/>:</strong></span>
      </td> 
      <td>
        <xsl:call-template name="ValidateAvailableSpace">
            <xsl:with-param name="avail_space">
              <xsl:value-of select="format-number(func:B_to_MB($total_value - $used_value), '0.0')"/>
            </xsl:with-param>
        </xsl:call-template>
      </td>
    </tr>
  </table>
</xsl:template>

<xsl:template name="TopDiskHogsTable">
  <xsl:param name="data"/>  

  <xsl:variable name="toggleElements">
    <xsl:if test="$data/users/user_list">
      <xsl:variable name="sorted_user_diskspace_list">
        <xsl:call-template name="ConvertToSortedNameValue">
          <xsl:with-param name="list" select="$data/users/user_list/item"/>
          <xsl:with-param name="name_field" select="'username'"/>
          <xsl:with-param name="value_field" select="'disk_used'"/>
          <xsl:with-param name="sort_field" select="'disk_used'"/>
          <xsl:with-param name="datatype" select="'number'"/>
          <xsl:with-param name="order" select="'descending'"/>
        </xsl:call-template>
      </xsl:variable>
      <item name="top3_homewebmail">
        <caption>
          <!--<xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'user (home + web + mail)'"/>
          </xsl:call-template>-->
          <xsl:value-of select="epl:_('user (home + web + mail)')"/>
        </caption>
        <content>
          <xsl:call-template name="NameValueTable">
            <xsl:with-param name="list" select="$sorted_user_diskspace_list"/>
            <xsl:with-param name="id" select="'top3_homewebmail'"/>
            <xsl:with-param name="limit" select="'3'"/>
            <xsl:with-param name="process">
              format-number(func:B_to_MB(value), '0.00')
            </xsl:with-param>
            <xsl:with-param name="draw_link">
              concat('/siteadmin/services/users/edit?username=', name)
            </xsl:with-param>
            <xsl:with-param name="priv_link">
              concat('/siteadmin/changeadmin','')
            </xsl:with-param>
            <xsl:with-param name="draw_test">
              1 - number(data/privileged)
            </xsl:with-param>
          </xsl:call-template>
        </content>
      </item>
    </xsl:if>
    <xsl:if test="$data/sendmail">
      <xsl:variable name="sorted_user_mbox_list">
        <xsl:if test="$data/sendmail">
          <xsl:call-template name="ConvertToSortedNameValue">
            <xsl:with-param name="list" select="$data/sendmail/user_mailboxes/item"/>
            <xsl:with-param name="name_field" select="'user'"/>
            <xsl:with-param name="value_field" select="'mailbox'"/>
            <xsl:with-param name="sort_field" select="'mailbox'"/>
            <xsl:with-param name="datatype" select="'number'"/>
            <xsl:with-param name="order" select="'descending'"/>
          </xsl:call-template>
        </xsl:if>
      </xsl:variable>
      <item name="top3_mailboxes">
        <caption>
          <!--<xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'mail usage'"/>
          </xsl:call-template>-->
          <xsl:value-of select="epl:_('mail usage')"/>
        </caption>
        <content>
          <xsl:call-template name="NameValueTable">
            <xsl:with-param name="list" select="$sorted_user_mbox_list"/>
            <xsl:with-param name="id" select="'top3_mailboxes'"/>
            <xsl:with-param name="limit" select="'3'"/>
            <xsl:with-param name="process">
              format-number(func:B_to_MB(value), '0.00')
            </xsl:with-param>
            <xsl:with-param name="draw_link">
              concat('/siteadmin/services/users/edit?username=', name)
            </xsl:with-param>
            <xsl:with-param name="priv_link">
              concat('/siteadmin/changeadmin','')
            </xsl:with-param>
            <xsl:with-param name="draw_test">
              1 - number(data/privileged)
            </xsl:with-param>
          </xsl:call-template>
        </content>
      </item>
    </xsl:if>
    <xsl:if test="$data/mysql/db_list/item">
      <item name="top3_dbusage">
        <xsl:variable name="sorted_db_list">
          <xsl:call-template name="ConvertToSortedNameValue">
            <xsl:with-param name="list" select="$data/mysql/db_list/item"/>
            <xsl:with-param name="name_field" select="'dbname'"/>
            <xsl:with-param name="value_field" select="'disk_used'"/>
            <xsl:with-param name="sort_field" select="'disk_used'"/>
            <xsl:with-param name="datatype" select="'number'"/>
            <xsl:with-param name="order" select="'descending'"/>
          </xsl:call-template>
        </xsl:variable>
        <caption>
          <!--<xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'database usage'"/>
          </xsl:call-template>-->
          <xsl:value-of select="epl:_('database usage')"/>
        </caption>
        <content>
          <xsl:call-template name="NameValueTable">
            <xsl:with-param name="list" select="$sorted_db_list"/>
            <xsl:with-param name="id" select="'top3_dbusage'"/>
            <xsl:with-param name="limit" select="'3'"/>
            <xsl:with-param name="process">
              format-number(func:B_to_MB(value), '0.00')
            </xsl:with-param>
            <xsl:with-param name="draw_link">
              concat('/siteadmin/services/mysql/editdatabase?dbname=', name)
            </xsl:with-param>
          </xsl:call-template>
        </content>
      </item>
    </xsl:if>
  </xsl:variable>

  <xsl:variable name="toggleList">
    <xsl:call-template name="join_toggle_nodes">
      <xsl:with-param name="toggleElements" select="$toggleElements"/>
    </xsl:call-template>
  </xsl:variable>

  <table width="100%" border="0" cellspacing="0" cellpadding="0">
    <tr>
      <td colspan="2">
        <span class="dashboard-subhead-2">
          <!--<xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'Top Disk Usage (MB):'"/>
          </xsl:call-template>-->
          <xsl:value-of select="epl:_('Top Disk Usage (MB):')"/>
          <xsl:call-template name="DrawSelect">
            <xsl:with-param name="toggleList" select="$toggleList"/>
            <xsl:with-param name="name" select="'topdiskhogs'"/>
            <xsl:with-param name="toggleElements" select="$toggleElements"/>
          </xsl:call-template>
        </span>
      </td>
    </tr>
  </table>

  <xsl:call-template name="DrawToggleElements">
    <xsl:with-param name="toggleElements">
      <xsl:copy-of select="$toggleElements"/>
    </xsl:with-param>
  </xsl:call-template>

  <script language="JavaScript">
    toggleDisplay('topdiskhogs', [<xsl:value-of select="$toggleList"/>]);
  </script>
</xsl:template>

<xsl:template name="DrawToggleElements">
  <xsl:param name="toggleElements"/>
  <xsl:for-each select="exsl:node-set($toggleElements)/item">
    <div id="{@name}" class="hidden">
      <xsl:copy-of select="content"/>
    </div>
  </xsl:for-each>
</xsl:template>

<xsl:template name="DiskSpaceDiv">
  <xsl:param name="data"/>
  <div class="dashboard-subhead-1">
    <!--<xsl:call-template name="gettext">
      <xsl:with-param name="default" select="'Disk Space (MB)'"/>
    </xsl:call-template>-->
    <xsl:value-of select="epl:_('Disk Space (MB)')"/>
  </div>
  <div>
    <table width="100%" cellpadding="0" cellspacing="2" border="0">
      <tr>
        <td width="48%">
          <xsl:call-template name="TotalUsedAvailTable">
            <xsl:with-param name="total_caption">
              <!--<xsl:call-template name="gettext">
                <xsl:with-param name="default" select="'Total'"/>
              </xsl:call-template>-->
              <xsl:value-of select="epl:_('Total')"/>
            </xsl:with-param>
            <xsl:with-param name="used_caption">
              <!--<xsl:call-template name="gettext">
                <xsl:with-param name="default" select="'Used'"/>
              </xsl:call-template>-->
              <xsl:value-of select="epl:_('Used')"/>
            </xsl:with-param>
            <xsl:with-param name="avail_caption">
              <!--<xsl:call-template name="gettext">
                <xsl:with-param name="default" select="'Available'"/>
              </xsl:call-template>-->
              <xsl:value-of select="epl:_('Available')"/>
            </xsl:with-param>
            <xsl:with-param name="used_value" select="$data/diskquota/current_diskspace"/>
            <xsl:with-param name="total_value" select="$data/diskquota/max_diskspace"/>
          </xsl:call-template>
        </td>
        <td width="4%"> </td> 
        <td>
          <xsl:call-template name="TopDiskHogsTable">
            <xsl:with-param name="data" select="$data"/>
          </xsl:call-template>
        </td>
      </tr>
    </table>
  </div>
</xsl:template>

<xsl:template name="ServiceStatusCell">
  <xsl:param name="caption"/>
  <xsl:param name="status"/>
  
  <xsl:if test="$status">
    <td>
      <xsl:choose>
        <xsl:when test="$status = 1">
          <img src="/static/images/status_up.gif" class="service-status"/>&#160;<xsl:value-of select="$caption"/>
        </xsl:when>
        <xsl:otherwise>
          <img src="/static/images/status_down.gif" class="service-status"/>&#160;<xsl:value-of select="$caption"/>
        </xsl:otherwise>
      </xsl:choose>
    </td>
  </xsl:if>

</xsl:template>

<xsl:template name="ServiceStatusDiv">
  <xsl:param name="data"/>
  <div class="dashboard-subhead-1">
    <!--<xsl:call-template name="gettext">
      <xsl:with-param name="default" select="'General'"/>
    </xsl:call-template>-->
    <xsl:value-of select="epl:_('General')"/>
  </div>
  <div>
    <table width="100%" cellpadding="0" cellspacing="2" border="0">
      <tr>
        <td>
          <table border="0" width="60%" cellspacing="2" cellpadding="0">
            <tr>
              <xsl:call-template name="ServiceStatusCell">
                <xsl:with-param name="caption">
                  <!--<xsl:call-template name="gettext">
                    <xsl:with-param name="default" select="'SSH'"/>
                  </xsl:call-template>-->
                  <xsl:value-of select="epl:_('SSH')"/>
                </xsl:with-param>
                <xsl:with-param name="status" select="$data/ssh/sshd_status"/>
              </xsl:call-template>
              
              <xsl:call-template name="ServiceStatusCell">
                <xsl:with-param name="caption">
                  <!--<xsl:call-template name="gettext">
                    <xsl:with-param name="default" select="'WWW'"/>
                  </xsl:call-template>-->
                  <xsl:value-of select="epl:_('WWW')"/>
                </xsl:with-param>
                <xsl:with-param name="status" select="$data/apache/httpd_status"/>
              </xsl:call-template>
              
              <xsl:call-template name="ServiceStatusCell">
                <xsl:with-param name="caption">
                  <!--<xsl:call-template name="gettext">
                    <xsl:with-param name="default" select="'FTP'"/>
                  </xsl:call-template>-->
                  <xsl:value-of select="epl:_('FTP')"/>
                </xsl:with-param>
                <xsl:with-param name="status" select="$data/proftpd/proftpd_status"/>
              </xsl:call-template>
              
              <xsl:call-template name="ServiceStatusCell">
                <xsl:with-param name="caption">
                  <!--<xsl:call-template name="gettext">
                    <xsl:with-param name="default" select="'Mail'"/>
                  </xsl:call-template>-->
                  <xsl:value-of select="epl:_('Mail')"/>
                </xsl:with-param>
                <xsl:with-param name="status" select="$data/sendmail/sendmail_status"/>
              </xsl:call-template>
              
              <xsl:call-template name="ServiceStatusCell">
                <xsl:with-param name="caption">
                  <!--<xsl:call-template name="gettext">
                    <xsl:with-param name="default" select="'POP'"/>
                  </xsl:call-template>-->
                  <xsl:value-of select="epl:_('POP')"/>
                </xsl:with-param>
                <xsl:with-param name="status" select="$data/imap/imap_status"/>
              </xsl:call-template>
              
              <xsl:call-template name="ServiceStatusCell">
                <xsl:with-param name="caption">
                  <!--<xsl:call-template name="gettext">
                    <xsl:with-param name="default" select="'MySQL'"/>
                  </xsl:call-template>-->
                  <xsl:value-of select="epl:_('MySQL')"/>
                </xsl:with-param>
                <xsl:with-param name="status" select="$data/mysql/mysqld_status"/>
              </xsl:call-template>

            </tr>
          </table>
        </td>
      </tr>
    </table>
  </div>
</xsl:template>

<xsl:template name="DataTransferGraphTable">
  <xsl:param name="data"/>
  <xsl:variable name="web" select="normalize-space($data/bandwidth/usage_by_category/web)"/>
  <xsl:variable name="ftp" select="normalize-space($data/bandwidth/usage_by_category/ftp)"/>
  <xsl:variable name="mail" select="normalize-space($data/bandwidth/usage_by_category/mail)"/>
  <xsl:choose>
  <xsl:when test="$web =0 and $ftp =0 and $mail =0">
    <table width="100%" border="0" cellspacing="0" cellpadding="0">
      <tr>
        <td colspan="2">&#160;&#160;</td>
      </tr> 
    </table>
  </xsl:when>
  <xsl:otherwise>
    <table width="100%" border="0" cellspacing="0" cellpadding="0">
      <tr>
  	<xsl:variable name="ispro" select="epl:isPro()"/>
  	<xsl:if test="$ispro = 'True'">
        <td colspan="2"><img src="/siteadmin/services/bandwidth/view_bwgraph?web_ftp_mail={$data/bandwidth/usage_by_category/web}-_-{$data/bandwidth/usage_by_category/ftp}-_-{$data/bandwidth/usage_by_category/mail}"/></td>
	</xsl:if>
      </tr> 
    </table>
  </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="DataTransferDiv">
  <xsl:param name="data"/>
  <xsl:variable name="ispro" select="epl:isPro()"/>
  <xsl:if test="$ispro = 'True'">
  <div class="dashboard-subhead-1">
    <!--<xsl:call-template name="gettext">
      <xsl:with-param name="default" select="'Data Transfer (MB)'"/>
    </xsl:call-template>-->
    <xsl:value-of select="epl:_('Data Transfer (MB)')"/>
  </div>
  <div>
    <table width="100%" cellpadding="0" cellspacing="2" border="0">
      <tr>
        <td width="48%">
          <xsl:call-template name="LimitLastThisTable">
            <xsl:with-param name="data" select="$data"/>
          </xsl:call-template>
        </td>
        <td width="4%"> </td> 
        <td>
          <xsl:call-template name="DataTransferGraphTable">
            <xsl:with-param name="data" select="$data"/>
          </xsl:call-template>
        </td>
      </tr>
    </table>
  </div>
</xsl:if>
</xsl:template>

<xsl:template name="SiteFullPane">
  <xsl:param name="data"/>

  <xsl:variable name="caption">
    <!--<xsl:call-template name="gettext">
      <xsl:with-param name="default" select="'up to date information on the big picture'"/>
    </xsl:call-template>-->
    <xsl:value-of select="epl:_('up to date information on the big picture')"/>
  </xsl:variable>
  <xsl:variable name="headerRow">
    <xsl:call-template name="FullPaneHeaderRow">
      <xsl:with-param name="icon" select="'/static/images/site-overview.gif'"/>
      <xsl:with-param name="caption">
        <!--<xsl:call-template name="gettext">
          <xsl:with-param name="default" select="'Site Overview'"/>
        </xsl:call-template>-->
        <xsl:value-of select="epl:_('Site Overview')"/>
      </xsl:with-param>
      <xsl:with-param name="desc" select="$caption"/>
      <xsl:with-param name="columns" select="'2'"/>
    </xsl:call-template>
  </xsl:variable>

      <table class="isp-dashboard" border="0" cellspacing="0" cellpadding="0"> 
          <xsl:copy-of select="$headerRow"/>
           <tr>
			<td>
				<table width="100%" height="100%" cellspacing="0">
					<tr>
					  <td class="isp-dashboard-section-top-l-without-title"/>
					  <td class="isp-dashboard-section-top-without-title"/>
					  <td class="isp-dashboard-section-top-r-without-title"/>
					</tr>

					<tr>
					  <td class="isp-dashboard-section-left"/>
					  <td valign="center" class="isp-dashboard-section-contents">
					  <!-- 					C O N T E N T S 					-->
					  
							<xsl:call-template name="GeneralDiv">
							  <xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
							<hr width="100%"/>
							<xsl:call-template name="ServiceStatusDiv">
							  <xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
							<xsl:if test="$data/diskquota">
 	 						  <hr width="100%"/>
							  <xsl:call-template name="DiskSpaceDiv">
								<xsl:with-param name="data" select="$data"/>
							  </xsl:call-template>
							</xsl:if>
							<xsl:if test="$data/bandwidth">
	 						  <hr width="100%"/>
							  <xsl:call-template name="DataTransferDiv">
								<xsl:with-param name="data" select="$data"/>
							  </xsl:call-template>
							</xsl:if>
						<!--  C O N T E N T S   E N D S -->
						</td>	
						<td class="isp-dashboard-section-right"/>
			        </tr>
			        <tr>
			          <td class="isp-dashboard-section-bottom-l"/>
				      <td class="isp-dashboard-section-bottom"/>
			          <td class="isp-dashboard-section-bottom-r"/>
			        </tr>
		      </table>
            </td>
          </tr>
        </table>
</xsl:template>

<xsl:template name="DrawTopTable">
 	<div class="subnav">
        <div style="left:0px" class="subnav-item">
	  			<a href="main" class="subnav-link-active">
                  <!--<xsl:call-template name="gettext">
                    <xsl:with-param name="default" select="'Dashboard'"/>
                  </xsl:call-template>-->
                  <xsl:value-of select="epl:_('Dashboard')"/>
                </a>	  	</div>		
		<div style="left:-10px" class="subnav-item">
              <a href="shortcuts">
                  <!--<xsl:call-template name="gettext">
                    <xsl:with-param name="default" select="'Shortcuts'"/>
                  </xsl:call-template>-->
                  <xsl:value-of select="epl:_('Shortcuts')"/>
              </a>	  	</div>
	</div>	    
</xsl:template>

<xsl:template name="HTMLPage">

  <xsl:param name="content" select="''"/>

  <html>
  <head>
    <link href="/static/css/site.global.css" rel="stylesheet" type="text/css"/>
    <xsl:call-template name="divToggle"/>
  </head>

  <xsl:choose>
      <xsl:when test="/site/statistics/siteinfo/site_showscreen='0'">
        <body>
        <xsl:call-template name="DrawTopTable">
        </xsl:call-template>
         <xsl:if test="/site/motd/child::node()[name() = 'entry']">
              <xsl:call-template name="drawMOTD">
              </xsl:call-template>
         </xsl:if>
        <xsl:copy-of select="$content"/>
        </body>
      </xsl:when>
      <xsl:otherwise>
        <body onload="javascript:userVar='new_user';window.open('new_user_form','helpWindow','resizable=no,scrollbars=no,height=350,width=450').focus();">
        <xsl:call-template name="DrawTopTable">
        </xsl:call-template>
         <xsl:if test="/site/motd/child::node()[name() = 'entry']">
              <xsl:call-template name="drawMOTD">
              </xsl:call-template>
         </xsl:if>
        <xsl:copy-of select="$content"/>
        </body>
      </xsl:otherwise>
  </xsl:choose>

  

  </html>

</xsl:template>

</xsl:stylesheet>
