<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE xsl:stylesheet [
    <!ENTITY nbsp "&#160;">
    <!ENTITY raquo "&#187;">
]>

<xsl:stylesheet
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:tgt="http://www.w3.org/1999/xhtml"
    xmlns:epl="http://www.ensim.com/epl50"
    xmlns:saxon="http://icl.com/saxon"
    exclude-result-prefixes="saxon epl"
    xmlns:fn="http://www.w3.org/2005/02/xpath-functions"
    xmlns:math="http://exslt.org/math"
    xmlns:sets="http://exslt.org/sets"
    xmlns:dyn="http://exslt.org/dynamic"
    extension-element-prefixes="dyn"
>

<xsl:output method="xml" indent="yes" />

<!-- This is the Site Admin's Dashboard XSL
     The Site Admin Dashboard ($frontend/static/xml/site.dashboard.xml) will be passed to this
-->


<xsl:param name="locale" select="'en_US'"/>
<xsl:variable name="trans">
  <xsl:variable name="file" select="concat('/usr/lib/opcenter/skins/mercury/locale/', $locale, '/LC_MESSAGES/strings.xml')"/>
  <xsl:choose>
    <xsl:when test="$locale='en_US'">
      <!-- Don't try to translate the original strings -->
      <xsl:value-of select="''"/>
    </xsl:when>
    <xsl:when test="document($file)">
      <xsl:value-of select="$file"/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="''"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:variable>

<xsl:template name="gettext">
  <xsl:param name="id" select="''"/>
  <xsl:param name="default" select="''"/>
  <xsl:choose>
    <xsl:when test="boolean($id) or boolean($default)">
      <xsl:choose>
        <xsl:when test="$trans != ''">
          <xsl:choose>
            <xsl:when test="$id != ''">
              <xsl:variable name="localization">
                <xsl:value-of select="document($trans)/strings/string[@id=$id]/msgstr"/>
              </xsl:variable>
              <xsl:choose>
                <xsl:when test="$localization != ''">
                  <xsl:value-of select="$localization"/>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="$default"/>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:when>
            <xsl:otherwise>
              <xsl:variable name="localization">
                <xsl:value-of select="document($trans)/strings/string[string(msgid)=$default]/msgstr"/>
              </xsl:variable>
              <xsl:choose>
                <xsl:when test="$localization != ''">
                  <xsl:value-of select="$localization"/>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="$default"/>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="$default"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="$default"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>  

<!-- Draws the subnavbar on the dashboard with 2 tags one for the dashboard and the other for
     shortcuts. The one that is clicked will be highlighted.
-->
<xsl:template name="DrawTopTable">
    <div class="subnav">
        <div style="left:0px" class="subnav-item">
            <a href="main">
            <xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'Dashboard'"/>
            </xsl:call-template>
            </a>    
        </div>
        <div style="left:-10px" class="subnav-item">
            <a href="shortcuts" class="subnav-link-active">
            <xsl:call-template name="gettext">
            <xsl:with-param name="default" select="'Shortcuts'"/>
            </xsl:call-template>
            </a>              
        </div>
    </div>
</xsl:template>


<xsl:template match="/">
 <xsl:variable name="site_dashboard_title" select="/sitedashboard/title/text()"/>
 <xsl:variable name="num_columns" select="/sitedashboard/columns/text()"/>
 <xsl:variable name="num_sections" select="count (/sitedashboard/section[not(dashboard-invisible)])"/>

 <!-- note: the `round' function rounds off the floating point number -->
 <xsl:variable name="num_rows" select="round ($num_sections div $num_columns)"/>

 <!-- see http://www.xml.com/pub/a/2001/05/07/xsltmath.html for some xsl math functions -->
 <xsl:variable name="section_width" select="floor (100 div $num_columns)"/>
 <xsl:variable name="section_height" select="floor (100 div $num_rows)"/>

 <html xmlns="http://www.w3.org/1999/xhtml">
  <head>
   <meta content="text/html; charset=ISO-8859-1" http-equiv="content-type" />
   <link href="/static/css/site.global.css" type="text/css" rel="stylesheet" />
   <title><xsl:value-of select="epl:_(string($site_dashboard_title))"/></title>
  </head>

<body>
    <!-- Draws the subnavbar on the dashboard-->
    <xsl:call-template name="DrawTopTable">
    </xsl:call-template> 
        
    <!-- First section of dashboard which contains site's usage information. -->
    <table class="isp-dashboard" cellspacing="0">
        <tr>
        <td colspan="2" class="isp-dashboard-title"><div><xsl:value-of select="epl:_('System Statistics')"/></div></td>
        </tr>         
        
        <tr>
        <td width="50%" height="100%">
        <table width="100%" height="100%"  cellspacing="0">
            <tr>
            <td class="isp-dashboard-section-top-l"></td>
            <td class="isp-dashboard-section-top"></td>
            <td class="isp-dashboard-section-top-r"></td>
            </tr>

            <tr>
            <th class="isp-dashboard-section-left"></th>
            <th class="isp-dashboard-section-head"></th>
            <th class="isp-dashboard-section-right"></th>
            </tr>
    
            <tr>
            <td class="isp-dashboard-section-left"></td>
            <td valign="center" class="isp-dashboard-section-contents">
            <table width="100%" height="100%" cellspacing="0">
                <tr>
                <td>
                <p><xsl:value-of select="epl:_('Disk Space')"/></p>
                </td>
                <!-- If diskquota is enabled the usage bar will be rendered otherwise not. -->
                <td class="right-align">
                <xsl:variable name="diskquotaEnabled" select="/sitedashboard/site/properties/diskquota/enabled" />
                <xsl:if test="$diskquotaEnabled = 1">
                <table width="100%" height="100%" cellspacing="0">
                    <tr>
                    <!-- Calculates the usage percentage of the diskspace and render's it in
                         a bar form. -->
                    <td>
                    <div class="server-stats">
                    <xsl:variable name="max_diskspace" select="/sitedashboard/site/statistics/diskquota/max_diskspace"/>
                    <xsl:variable name="max_diskspace_MB" select="floor($max_diskspace div 1048576)"/>
                    <xsl:variable name="current_diskspace" select="/sitedashboard/site/statistics/diskquota/current_diskspace"/>
                    <xsl:variable name="current_diskspace_MB" select="floor($current_diskspace div 1048576)"/>
                    <xsl:variable name="disk_usage_perc" select="floor($current_diskspace_MB div $max_diskspace_MB * 100)" />
                    <div class="disk-info">
                    <div class="disk-usage-bar" style="width:{$disk_usage_perc}%">&#xA0;</div>  
                    <div class="disk-usage-text"><xsl:value-of select="$disk_usage_perc"/><xsl:value-of select="epl:_('% used')"/></div>
                    </div>
                    <!-- Displays the actual values of used and total diskquota. -->
                    <td class="center-align">
                    <xsl:value-of select="$current_diskspace_MB"/>
                    /
                    <xsl:value-of select="$max_diskspace_MB"/><xsl:value-of select="epl:_('MB Used')"/>
                    </td>
                    </div>
                    </td>
                    </tr>
                </table>
                </xsl:if>
                <xsl:if test="$diskquotaEnabled = 0">
                <xsl:value-of select="epl:_('N/A')"/>
                </xsl:if>
                </td>
                </tr>

                <tr>
                <td>
                <p><xsl:value-of select="epl:_('Bandwidth')"/></p>
                </td>
                <!-- If bandwidth is enabled the usage bar will be rendered otherwise not. -->
                <td class="right-align">                    
                <xsl:variable name="bandwidthEnabled" select="/sitedashboard/site/properties/bandwidth/enabled" />
                <xsl:if test="$bandwidthEnabled = 1">
                <table width="100%" height="100%" cellspacing="0">
                    <tr>
                    <!-- Calculates the usage percentage of the bandwidth and render's it in
                         a bar form. -->
                    <td>
                    <div class="server-stats">
                    <xsl:variable name="max_bandwidth" select="/sitedashboard/site/statistics/bandwidth/limit"/>
                    <xsl:variable name="max_bandwidth_MB" select="floor($max_bandwidth div 1048576)"/>
                    <xsl:variable name="current_bandwidth" select="/sitedashboard/site/statistics/bandwidth/this_month_usage"/>
                    <xsl:variable name="current_bandwidth_MB" select="floor($current_bandwidth div 1048576)"/>
                    <xsl:variable name="bandwidth_usage_perc" select="floor($current_bandwidth_MB div $max_bandwidth_MB * 100)" />
                    <div class="disk-info">
                    <div class="disk-usage-bar" style="width:{$bandwidth_usage_perc}%">&#xA0;</div>  
                    <div class="disk-usage-text"><xsl:value-of select="$bandwidth_usage_perc"/><xsl:value-of select="epl:_('% used')"/></div>
                    </div>
                    <!-- Displays the actual values of used and total bandwidth. -->
                    <td class="center-align">
                    <xsl:value-of select="$current_bandwidth_MB"/>
                    /
                    <xsl:value-of select="$max_bandwidth_MB"/><xsl:value-of select="epl:_('MB Used')"/>
                    </td>
                    </div>
                    </td>
                    </tr>
                </table>
                </xsl:if>
                <xsl:if test="$bandwidthEnabled = 0">
                <xsl:value-of select="epl:_('N/A')"/>
                </xsl:if>
                </td>
                </tr>
            </table>
            </td>
            <td class="isp-dashboard-section-right"></td>
            </tr>

            <tr>
            <td class="isp-dashboard-section-bottom-l"></td>
            <td class="isp-dashboard-section-bottom"></td>
            <td class="isp-dashboard-section-bottom-r"></td>
            </tr>
        </table>
        </td>

        <td width="50%" height="100%">
        <table width="100%" height="100%" cellspacing="0">
            <tr>
            <td class="isp-dashboard-section-top-l"></td>
            <td class="isp-dashboard-section-top"></td>
            <td class="isp-dashboard-section-top-r"></td>
            </tr>

            <tr>
            <th class="isp-dashboard-section-left"></th>
            <th class="isp-dashboard-section-head"></th>
            <th class="isp-dashboard-section-right"></th>
            </tr>

            <tr>
            <td class="isp-dashboard-section-left"></td>
            <td valign="center" class="isp-dashboard-section-contents">
            <table width="100%" cellspacing="0">
                <tr>
                <td>
                <p><xsl:value-of select="epl:_('Users')"/></p>
                <!-- If users service is enabled the stats are displayed otherwise 0 is displayed for used and total users values. -->
                </td>
                <td class="right-align">
                <xsl:if test="/sitedashboard/site/properties/users/enabled/text() = 1">
                <xsl:value-of select="/sitedashboard/site/statistics/users/user_count" />
                /
                <xsl:value-of select="/sitedashboard/site/statistics/users/user_max" />
                </xsl:if>
                           
                <xsl:if test="/sitedashboard/site/properties/users/enabled/text() = 0">
                0/0
                </xsl:if>
                </td>
                </tr>

                <tr>
                <td>
                <p><xsl:value-of select="epl:_('Database')"/></p>
                <!-- If mysql service is not enabled 0 is displayed for used and total values. -->
                </td>
                <td class="right-align">
                <xsl:if test="/sitedashboard/site/properties/mysql/enabled/text() = 1">
                <xsl:value-of select="/sitedashboard/site/statistics/mysql/db_count" />
                /
                <xsl:value-of select="/sitedashboard/site/statistics/mysql/db_max" />
                </xsl:if>
                <xsl:if test="/sitedashboard/site/properties/mysql/enabled/text() = 0">
                0/0
                </xsl:if>
                </td>
                </tr>

                <tr>
                <td>
                <p><xsl:value-of select="epl:_('Subdomains')"/></p>
                <!-- If subdomain service is not enabled 0 is displayed for used and max values. -->
                </td>
                <td class="right-align">
                <xsl:if test="/sitedashboard/site/properties/subdomain/enabled/text() = 1">
                <xsl:value-of select="/sitedashboard/site/statistics/subdomain/subdomain_count/usage/" />
                /
                <xsl:value-of select="/sitedashboard/site/statistics/subdomain/subdomain_max" />
                </xsl:if>
                <xsl:if test="/sitedashboard/site/properties/subdomain/enabled/text() = 0">
                0/0
                </xsl:if>
                </td>
                </tr>

                <tr>
                <td>
                <p><xsl:value-of select="epl:_('Web Document Path')"/></p>
                </td>
                <td class="right-align">
                <xsl:value-of select="/sitedashboard/site/statistics/apache/html_root" />
                </td>
                </tr>

                <tr>
                <td>
                <p><xsl:value-of select="epl:_('CGI Document Path')"/></p>
                </td>
                <td class="right-align">
                <xsl:value-of select="/sitedashboard/site/statistics/cgi/cgi_root" />
                </td>
                </tr>
            </table>
            </td>

            <td class="isp-dashboard-section-right"></td>
            </tr>

            <tr>
            <td class="isp-dashboard-section-bottom-l"></td>
            <td class="isp-dashboard-section-bottom"></td>
            <td class="isp-dashboard-section-bottom-r"></td>
            </tr>
        </table>
        </td>
        </tr>
    </table>                

        <!-- Second section on the dashboard that contains all the shortcuts for items on the
            dashboard.  -->
        <table class="isp-dashboard" cellspacing="0">
            <tr>
            <td colspan="{$num_columns}" class="isp-dashboard-title"><div><xsl:value-of select="epl:_(string($site_dashboard_title))"/></div></td>
            </tr>
  
            <!--<xsl:for-each select="sitedashboard/section">-->
            <xsl:for-each select="sitedashboard/section[not(dashboard-invisible)]">
            <xsl:if test="(position() mod $num_columns) = 1">
                <!-- record the 1-based position of this element -->
            <xsl:variable name="currpos" select="count(. | sets:leading(/sitedashboard/section,.))"/>
            <tr>
            <xsl:for-each select=". | ./following-sibling::node()[name() = 'section'][position() &lt; $num_columns]">
            <xsl:if test="not(dashboard-invisible)">
            <td width="{$section_width}%" height="{$section_height}%">

            <!-- one table per section -->
            <table width="100%" height="100%"  cellspacing="0">
                <tr>
                <td class="isp-dashboard-section-top-l"></td>
                <td class="isp-dashboard-section-top"></td>
                <td class="isp-dashboard-section-top-r"></td>
                </tr>

                <tr>
	        <th class="isp-dashboard-section-left"></th>
                <!-- first row is the caption of the section -->
       	        <th class="isp-dashboard-section-head"><xsl:value-of select="epl:_(string(caption))"/></th>
	        <th class="isp-dashboard-section-right"></th>
                </tr>

                <tr>
	        <td class="isp-dashboard-section-left"></td>
                <!-- second row is the actual content of the section -->
                <td valign="center" class="isp-dashboard-section-contents">
                <xsl:variable name="section_img" select="image"/>
                <img class="db-icon" src="{$section_img}" />

                <xsl:for-each select="./item[not(dashboard-invisible)]">
                <xsl:choose>
                    <xsl:when test="./child::node()[name() = 'service']">
                        <xsl:variable name="enabledservice" select="./service" />
                        <xsl:variable name="serviceEnabledXPath" select='concat("/sitedashboard/site/properties/",$enabledservice,"/enabled/text()")'/>
                        <xsl:variable name="service" select="dyn:evaluate($serviceEnabledXPath)"/>
                        <xsl:if test="$service = 1">
                        <xsl:variable name="url" select="link/text()"/>
                        <p><a href="{$url}"><xsl:value-of select="epl:_(string(display/text()))"/></a></p>
                        </xsl:if>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:variable name="url" select="link/text()"/>
                        <p><a href="{$url}"><xsl:value-of select="epl:_(string(display/text()))"/></a></p>
                    </xsl:otherwise>
                </xsl:choose> 
                </xsl:for-each>
                </td>
	        <td class="isp-dashboard-section-right"></td>
                </tr>

                <tr>
                <td class="isp-dashboard-section-bottom-l"></td>
                <td class="isp-dashboard-section-bottom"></td>
                <td class="isp-dashboard-section-bottom-r"></td>
                </tr>

            </table>
            </td>
            </xsl:if>
            </xsl:for-each>
            </tr>
            </xsl:if>
            </xsl:for-each>
        </table>
    </body>
</html>

</xsl:template>
</xsl:stylesheet>
