<?xml version="1.0" encoding="utf-8"?>
<!--
    $Id: user.dashboard.xsl,v 1.2 2008/03/04 16:08:17 asmirnova Exp $
    $Log: user.dashboard.xsl,v $
    Revision 1.2  2008/03/04 16:08:17  asmirnova
    Added "Reloaded" design

    Revision 1.2  2008/02/21 20:31:50  agordienko
    added paralels logo and copyright

    Revision 1.1.1.1  2007/12/17 10:08:22  andrew
    initial swsoft import

    Revision 1.5  2006/04/12 13:14:10  mansoor
    XSL stylesheets need to stringify the XML nodes before calling the epl:_ localizer function

    Revision 1.4  2006/02/09 11:47:18  msahani
    Removed lang tags and replaced them with _() function for internationalization.

    Revision 1.3  2006/02/07 13:47:39  msahani
    Removed all occurance of epleval and optimized the xsls.

-->
<xsl:stylesheet
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:fn="http://www.w3.org/2005/02/xpath-functions"
    xmlns:math="http://exslt.org/math"
    xmlns:sets="http://exslt.org/sets"
>

<xsl:output method="xml" indent="yes" />

<!-- This is the Site Users Dashboard XSL
     The Site Users Dashboard ($frontend/static/xml/user.dashboard.xml) will be passed to this
-->

<xsl:template match="/">
 <xsl:variable name="user_dashboard_title" select="/userdashboard/title/text()"/>
 <xsl:variable name="num_columns" select="/userdashboard/columns/text()"/>
 <xsl:variable name="num_sections" select="count (/userdashboard/section)"/>

 <!-- note: the `round' function rounds off the floating point number -->
 <xsl:variable name="num_rows" select="round ($num_sections div $num_columns)"/>

 <!-- see http://www.xml.com/pub/a/2001/05/07/xsltmath.html for some xsl math functions -->
 <xsl:variable name="section_width" select="floor (100 div $num_columns)"/>
 <xsl:variable name="section_height" select="floor (100 div $num_rows)"/>

 <html xmlns="http://www.w3.org/1999/xhtml">
  <head>
   <meta content="text/html; charset=ISO-8859-1" http-equiv="content-type" />
   <link href="/static/css/user.global.css" type="text/css" rel="stylesheet" />
   <title><xsl:value-of select="epl:_(string($user_dashboard_title))"/></title>
  </head>

<body>
 <table class="isp-dashboard" cellspacing="0">
  <tr>
   <td colspan="{$num_columns}" class="isp-dashboard-title"><div><xsl:value-of select="epl:_(string($user_dashboard_title))"/></div></td>
  </tr>

  <xsl:for-each select="userdashboard/section[not(dashboard-invisible)][(position() mod $num_columns) = 1]">
  <!-- record the 1-based position of this element -->
  <xsl:variable name="currpos" select="count(. | sets:leading(/userdashboard/section,.))"/>
  <tr>
   <xsl:for-each select=". | ./following-sibling::node()[name() = 'section'][position() &lt; $num_columns]">
   <td width="{$section_width}%" height="{$section_height}%">

    <!-- one table per section -->
     <table width="100%" height="100%"  cellspacing="0">

     <tr>
      <td class="isp-dashboard-section-top-l"></td>
      <td class="isp-dashboard-section-top"></td>
      <td class="isp-dashboard-section-top-r"></td>
     </tr>

      <tr>
	 <th class="isp-dashboard-section-left"></th>
       <!-- first row is the caption of the section -->
       	 <th class="isp-dashboard-section-head"><xsl:value-of select="epl:_(string(caption))"/></th>
	 <th class="isp-dashboard-section-right"></th>
      </tr>

      <tr>
	 <td class="isp-dashboard-section-left"></td>
       <!-- second row is the actual content of the section -->
       <td valign="center" class="isp-dashboard-section-contents">
        <xsl:variable name="section_img" select="image"/>
        <img src="{$section_img}" class="db-icon"/>

        <xsl:for-each select="./item[not(dashboard-invisible)]">
         <xsl:variable name="url" select="link/text()"/>
         <p><a href="{$url}"><xsl:value-of select="epl:_(string(display/text()))"/></a></p>
        </xsl:for-each>
       </td>
	 <td class="isp-dashboard-section-right"></td>
      </tr>

     <tr>
      <td class="isp-dashboard-section-bottom-l"></td>
      <td class="isp-dashboard-section-bottom"></td>
      <td class="isp-dashboard-section-bottom-r"></td>
     </tr>

     </table>
   </td>

   </xsl:for-each>
  </tr>

  </xsl:for-each>
 </table>
</body>
</html>

</xsl:template>
</xsl:stylesheet>
