<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE xsl:stylesheet [
    <!ENTITY nbsp "&#160;">
    <!ENTITY raquo "&#187;">
]>

<xsl:stylesheet
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:tgt="http://www.w3.org/1999/xhtml"
    xmlns:epl="http://www.ensim.com/epl50"
    xmlns:saxon="http://icl.com/saxon"
    exclude-result-prefixes="saxon epl"
    xmlns:fn="http://www.w3.org/2005/02/xpath-functions"
    xmlns:math="http://exslt.org/math"
    xmlns:sets="http://exslt.org/sets"
    xmlns:dyn="http://exslt.org/dynamic"
    xmlns:func="http://exslt.org/functions"
    extension-element-prefixes="dyn func"
>

<xsl:output method="xml" indent="yes" />

<!-- This is the Site Admin's Dashboard XSL
     The Site Admin Dashboard ($frontend/static/xml/site.dashboard.xml) will be passed to this
-->

<!-- This function gets an item node and checks if that node is to be displayed on the dashboard or
not. For this it checks if the service of that item is enabled or not. If no service node is present
or if service node is empty then it displays the item.
-->
<func:function name="func:isItemDisplayable">
 <xsl:param name="item_node"/>
 <xsl:variable name="enabledservice" select="$item_node/service/text()" />
 <xsl:variable name="ispro" select="epl:isPro()"/>
 <xsl:choose>
  <xsl:when test="$item_node/service1">
   <xsl:variable name="enabledservice1" select="$item_node/service1/text()" />
   <xsl:variable name="serviceEnabledXPath" select='concat("/sitedashboard/site/properties/",$enabledservice,"/enabled/text()")'/>
   <xsl:variable name="service" select="dyn:evaluate($serviceEnabledXPath)"/>
   <xsl:variable name="service1EnabledXPath" select='concat("/sitedashboard/site/properties/",$enabledservice1,"/enabled/text()")'/>
   <xsl:variable name="service1" select="dyn:evaluate($service1EnabledXPath)"/>
   <xsl:if test="$service=1 and $service1=1">
    <func:result select="false()"/>
   </xsl:if>
   <xsl:if test="$service=1 and $service1=0">
    <func:result select="true()"/>
   </xsl:if>
  </xsl:when>
  <xsl:otherwise>
   <xsl:choose>
    <xsl:when test="$item_node/child::node()[name() = 'service'] and $item_node/service/text()">
     <xsl:choose>
      <xsl:when test="$item_node/child::node()[name() = 'proenabled']">
       <xsl:if test = "$ispro = 'True'">
        <xsl:variable name="serviceEnabledXPath" select='concat("/sitedashboard/site/properties/",$enabledservice,"/enabled/text()")'/>
        <xsl:variable name="service" select="dyn:evaluate($serviceEnabledXPath)"/>
        <xsl:choose>
         <xsl:when test="$service = 1">
          <xsl:choose>
           <xsl:when test="$enabledservice = 'bind'">
            <xsl:if test="/sitedashboard/site/properties/bind/zone_mgmt/text() = 1">
             <func:result select="true()"/>
            </xsl:if>
           </xsl:when>
           <xsl:otherwise>
            <func:result select="true()"/>
           </xsl:otherwise>
          </xsl:choose>
         </xsl:when>
         <xsl:otherwise>
          <func:result select="false()"/>
         </xsl:otherwise>
        </xsl:choose>
       </xsl:if>
      </xsl:when>
      <xsl:otherwise>
       <xsl:variable name="serviceEnabledXPath" select='concat("/sitedashboard/site/properties/",$enabledservice,"/enabled/text()")'/>
       <xsl:variable name="service" select="dyn:evaluate($serviceEnabledXPath)"/>
       <xsl:choose>
        <xsl:when test="$service = 1">
         <xsl:choose>
          <xsl:when test="$enabledservice = 'bind'">
           <xsl:if test="/sitedashboard/site/properties/bind/zone_mgmt/text() = 1">
            <func:result select="true()"/>
           </xsl:if>
          </xsl:when>
          <xsl:otherwise>
           <func:result select="true()"/>
          </xsl:otherwise>
         </xsl:choose>
        </xsl:when>
        <xsl:otherwise>
         <func:result select="false()"/>
        </xsl:otherwise>
       </xsl:choose>
      </xsl:otherwise>
     </xsl:choose>
    </xsl:when>
    <xsl:otherwise>
     <func:result select="true()"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:otherwise>
 </xsl:choose>
</func:function>

<!-- This iterates over each item node in the current select and calls isItemDisplayable() function
for each item.
-->
<xsl:key name="displayItem" match="item" use="func:isItemDisplayable(.)"/>

<!-- This function checks if a section is to be displayed on the dashboard. A section has to be
displayed if there is even one item under it which is displayable.
-->
<func:function name="func:isSectionDisplayable">
 <xsl:param name="section_node"/>
 <xsl:choose>
  <xsl:when test="count(key('displayItem','true')[../caption/text() = $section_node/caption/text()]) = 0">
   <func:result select="false()"/>
  </xsl:when>
  <xsl:otherwise>
   <func:result select="true()"/>
  </xsl:otherwise>
 </xsl:choose>
</func:function>

<!-- Draws the subnavbar on the dashboard with 2 tags one for the dashboard and the other for
     shortcuts. The one that is clicked will be highlighted.
-->
<xsl:template name="DrawTopTable">
 <div class="subnav">
  <div style="left:0px" class="subnav-item">
   <a href="main">
    <xsl:value-of select="epl:_('Dashboard')"/>
   </a>    
  </div>
  <div style="left:-10px" class="subnav-item">
   <a href="shortcuts" class="subnav-link-active">
    <xsl:value-of select="epl:_('Shortcuts')"/>
   </a>              
  </div>
 </div>
</xsl:template>

<xsl:template match="/">
 <xsl:variable name="site_dashboard_title" select="/sitedashboard/title/text()"/>
 <xsl:variable name="num_columns" select="/sitedashboard/columns/text()"/>
 <xsl:variable name="num_sections" select="count (/sitedashboard/section[not(dashboard-invisible)])"/>

 <!-- note: the `round' function rounds off the floating point number -->
 <xsl:variable name="num_rows" select="round ($num_sections div $num_columns)"/>

 <!-- see http://www.xml.com/pub/a/2001/05/07/xsltmath.html for some xsl math functions -->
 <xsl:variable name="section_width" select="floor (100 div $num_columns)"/>
 <xsl:variable name="section_height" select="floor (100 div $num_rows)"/>

 <html xmlns="http://www.w3.org/1999/xhtml">
  <head>
   <meta content="text/html; charset=ISO-8859-1" http-equiv="content-type" />
   <link href="/static/css/site.global.css" type="text/css" rel="stylesheet" />
   <title><xsl:value-of select="epl:_(string(/sitedashboard/title/text()))"/></title>
  </head>

  <body>
   <!-- Draws the subnavbar on the dashboard-->
   <xsl:call-template name="DrawTopTable">
   </xsl:call-template> 
        
   <!-- First section of dashboard which contains site's usage information. -->
   <table class="isp-dashboard" cellspacing="0">
    <tr>
     <td colspan="2" class="isp-dashboard-title"><div><xsl:value-of select="epl:_('System Statistics')"/></div></td>
    </tr>         
        
    <tr>
     <td width="50%" height="100%">
      <table width="100%" height="100%"  cellspacing="0">
       <tr>
        <td class="isp-dashboard-section-top-l"></td>
        <td class="isp-dashboard-section-top"></td>
        <td class="isp-dashboard-section-top-r"></td>
       </tr>

       <tr>
        <th class="isp-dashboard-section-left"></th>
        <th class="isp-dashboard-section-head"></th>
        <th class="isp-dashboard-section-right"></th>
       </tr>
    
       <tr>
        <td class="isp-dashboard-section-left"></td>
        <td valign="center" class="isp-dashboard-section-contents">
         <table width="100%" height="100%" cellspacing="0">
          <tr>
           <td>
            <p><xsl:value-of select="epl:_('Disk Space')"/></p>
           </td>
           <!-- If diskquota is enabled the usage bar will be rendered otherwise not. -->
           <td class="right-align">
             <xsl:variable name="diskquotaEnabled" select="/sitedashboard/site/properties/diskquota/enabled" />
             <xsl:variable name="max_diskspace" select="/sitedashboard/site/statistics/diskquota/max_diskspace"/>
             <xsl:variable name="max_diskspace_MB" select="floor($max_diskspace div 1048576)"/>
             <xsl:variable name="current_diskspace" select="/sitedashboard/site/statistics/diskquota/current_diskspace"/>
             <xsl:variable name="current_diskspace_MB" select="floor($current_diskspace div 1048576)"/>
             <xsl:variable name="disk_usage_perc" select="round($current_diskspace div $max_diskspace * 100)" />
             <table width="100%" height="100%" cellspacing="0">
              <tr>
               <!-- Calculates the usage percentage of the diskspace and render's it in
               a bar form. -->
               <td>
                <div class="server-stats">
                 <xsl:choose>
                  <xsl:when test="$max_diskspace = 0 or $diskquotaEnabled = 0">
                   <div class="no-data-text"><xsl:value-of select="epl:_('N/A')"/></div>
                  </xsl:when>
                  <xsl:otherwise>
                   <div class="disk-info">
                    <xsl:choose>
                     <xsl:when test="$disk_usage_perc &gt; 100">
                      <div class="disk-usage-bar" style="width:100%">&#xA0;</div>
                      <div class="disk-usage-text">100%<xsl:value-of select="epl:_(' used')"/></div>
                     </xsl:when>
                     <xsl:otherwise>
                      <div class="disk-usage-bar" style="width:{$disk_usage_perc}%">&#xA0;</div>
                      <div class="disk-usage-text"><xsl:value-of select="$disk_usage_perc"/>%<xsl:value-of select="epl:_(' used')"/></div>
                     </xsl:otherwise>
                    </xsl:choose>
                   </div>
                  </xsl:otherwise>
                 </xsl:choose>
                </div>                    
               </td>
              </tr> 
              <!-- Displays the actual values of used and total diskquota. -->
              <tr>
               <td class="center-align">
                <xsl:value-of select="$current_diskspace_MB"/>
                /                
                <xsl:choose>
                <xsl:when test="$max_diskspace = 0 or $diskquotaEnabled = 0">
                 <xsl:value-of select="epl:_('Unlimited MB')"/>
                </xsl:when>
                <xsl:otherwise>
                 <xsl:value-of select="$max_diskspace_MB"/><xsl:value-of select="epl:_('MB')"/><xsl:value-of select="epl:_(' Used')"/>
                </xsl:otherwise>
                </xsl:choose>
               </td>
              </tr>
             </table>
           </td>
          </tr>

          <tr>
           <td>
  	    <xsl:variable name="ispro" select="epl:isPro()"/>
            <xsl:if test="$ispro = 'True'">
            <p><xsl:value-of select="epl:_('Bandwidth')"/></p>
            </xsl:if>
           </td>
           <!-- If bandwidth is enabled the usage bar will be rendered otherwise not. -->
           <td class="right-align">                    
  	    <xsl:variable name="ispro" select="epl:isPro()"/>
            <xsl:variable name="bandwidthEnabled" select="/sitedashboard/site/properties/bandwidth/enabled" />
            <xsl:if test="$ispro = 'True'">
            <xsl:if test="$bandwidthEnabled = 1">
             <xsl:variable name="max_bandwidth" select="/sitedashboard/site/statistics/bandwidth/limit"/>
             <xsl:variable name="max_bandwidth_MB" select="floor($max_bandwidth div 1048576)"/>
             <xsl:variable name="current_bandwidth" select="/sitedashboard/site/statistics/bandwidth/this_month_usage"/>
             <xsl:variable name="current_bandwidth_MB" select="floor($current_bandwidth div 1048576)"/>
             <xsl:variable name="bandwidth_usage_perc" select="round($current_bandwidth div $max_bandwidth * 100)" />
             <table width="100%" height="100%" cellspacing="0">
              <tr>
               <!-- Calculates the usage percentage of the bandwidth and render's it in
               a bar form. -->
               <td>
                <div class="server-stats">
                 <xsl:choose>
                  <xsl:when test="$max_bandwidth = 0">
                   <div class="no-data-text"><xsl:value-of select="epl:_('N/A')"/></div>
                  </xsl:when>
                  <xsl:otherwise>
                   <div class="disk-info">
                    <xsl:choose>
                     <xsl:when test="$bandwidth_usage_perc &gt; 100">
                      <div class="disk-usage-bar" style="width:100%">&#xA0;</div>
                      <div class="disk-usage-text">100%<xsl:value-of select="epl:_(' used')"/></div>
                     </xsl:when>
                     <xsl:otherwise>
                      <div class="disk-usage-bar" style="width:{$bandwidth_usage_perc}%">&#xA0;</div>
                      <div class="disk-usage-text"><xsl:value-of select="$bandwidth_usage_perc"/>%<xsl:value-of select="epl:_(' used')"/></div>
                     </xsl:otherwise>
                    </xsl:choose>
                   </div>
                  </xsl:otherwise>
                 </xsl:choose>
                </div> 
               </td>
              </tr> 
              <!-- Displays the actual values of used and total bandwidth. -->
              <tr>
               <td class="center-align">
                <xsl:value-of select="$current_bandwidth_MB"/>
                /
                <xsl:choose>
                 <xsl:when test="$max_bandwidth = 0">
                  <xsl:value-of select="epl:_('Unlimited MB')"/>
                 </xsl:when>
                 <xsl:otherwise>
                  <xsl:value-of select="$max_bandwidth_MB"/><xsl:value-of select="epl:_('MB Used')"/>
                 </xsl:otherwise>
                </xsl:choose> 
               </td>
              </tr>
             </table>
            </xsl:if>
            </xsl:if>
            <xsl:if test="$bandwidthEnabled = 0">
             <xsl:value-of select="epl:_('N/A')"/>
            </xsl:if>
           </td>
          </tr>
         </table>
        </td>
        <td class="isp-dashboard-section-right"></td>
       </tr>

       <tr>
        <td class="isp-dashboard-section-bottom-l"></td>
        <td class="isp-dashboard-section-bottom"></td>
        <td class="isp-dashboard-section-bottom-r"></td>
       </tr>
      </table>
     </td>
     <td width="50%" height="100%">
      <table width="100%" height="100%" cellspacing="0">
       <tr>
        <td class="isp-dashboard-section-top-l"></td>
        <td class="isp-dashboard-section-top"></td>
        <td class="isp-dashboard-section-top-r"></td>
       </tr>
       <tr>
        <th class="isp-dashboard-section-left"></th>
        <th class="isp-dashboard-section-head"></th>
        <th class="isp-dashboard-section-right"></th>
       </tr>
       <tr>
        <td class="isp-dashboard-section-left"></td>
        <td valign="center" class="isp-dashboard-section-contents">
         <table width="100%" cellspacing="0">
          <tr>
           <td>
            <p><xsl:value-of select="epl:_('Users')"/></p>
            <!-- If users service is enabled the stats are displayed otherwise 0 is displayed for used and total users values. -->
           </td>
           <td class="right-align">
            <xsl:if test="/sitedashboard/site/properties/users/enabled/text() = 1">
             <xsl:value-of select="/sitedashboard/site/statistics/users/user_count" />
             /
             <xsl:value-of select="/sitedashboard/site/statistics/users/user_max" />
            </xsl:if>
                         
            <xsl:if test="/sitedashboard/site/properties/users/enabled/text() = 0">
             0/0
            </xsl:if>
           </td>
          </tr>
          <tr>
           <td>
            <p><xsl:value-of select="epl:_('Database')"/></p>
            <!-- If mysql service is not enabled 0 is displayed for used and total values. -->
           </td>
           <td class="right-align">
            <xsl:if test="/sitedashboard/site/properties/mysql/enabled/text() = 1">
             <xsl:value-of select="/sitedashboard/site/statistics/mysql/db_count" />
             /
             <xsl:value-of select="/sitedashboard/site/statistics/mysql/db_max" />
            </xsl:if>
            <xsl:if test="/sitedashboard/site/properties/mysql/enabled/text() = 0">
             0/0
            </xsl:if>
           </td>
          </tr>
          <tr>
           <td>
            <p><xsl:value-of select="epl:_('Subdomains')"/></p>
            <!-- If subdomain service is not enabled 0 is displayed for used and max values. -->
           </td>
           <td class="right-align">
            <xsl:if test="/sitedashboard/site/properties/subdomain/enabled/text() = 1">
             <xsl:value-of select="/sitedashboard/site/statistics/subdomain/subdomain_count/usage" />
             /
             <xsl:choose>
                <xsl:when test="/sitedashboard/site/statistics/subdomain/subdomain_max=-1">
                 <xsl:value-of select="epl:_('Unlimited')"/>
                </xsl:when>
                <xsl:otherwise>
                 <xsl:value-of select="/sitedashboard/site/statistics/subdomain/subdomain_max" />
                </xsl:otherwise>
             </xsl:choose>
            </xsl:if>
            <xsl:if test="/sitedashboard/site/properties/subdomain/enabled/text() = 0">
             0/0
            </xsl:if>
           </td>
          </tr>
          <tr>
           <td>
            <p><xsl:value-of select="epl:_('Web Document Path')"/></p>
           </td>
           <td class="right-align">
            <xsl:value-of select="/sitedashboard/site/statistics/apache/html_root" />
           </td>
          </tr>
          <tr>
           <td>
            <p><xsl:value-of select="epl:_('CGI Document Path')"/></p>
            </td>
            <td class="right-align">
             <xsl:value-of select="/sitedashboard/site/statistics/cgi/cgi_root" />
            </td>
           </tr>
          </table>
         </td>
         <td class="isp-dashboard-section-right"></td>
        </tr>
        <tr>
         <td class="isp-dashboard-section-bottom-l"></td>
         <td class="isp-dashboard-section-bottom"></td>
         <td class="isp-dashboard-section-bottom-r"></td>
        </tr>
       </table>
      </td>
     </tr>
    </table>                

    <!-- Second section on the dashboard that contains all the shortcuts for items on the dashboard.  -->
    
    <table class="isp-dashboard" cellspacing="0">
     <tr>
      <td colspan="{$num_columns}" class="isp-dashboard-title"><div><xsl:value-of select="epl:_(string(/sitedashboard/title/text()))"/></div></td>
     </tr>
     <xsl:for-each select="sitedashboard/section[not(dashboard-invisible) and (func:isSectionDisplayable(.) = 'true')]">
      <xsl:if test="(position() mod $num_columns) = 1">
       <!-- record the 1-based position of this element -->
       <tr>
        <xsl:for-each select=". | ./following-sibling::node()[(name() = 'section') and (func:isSectionDisplayable(.) = 'true')][position() &lt; $num_columns]"> 
         <xsl:if test="not(dashboard-invisible)">
          <td width="{$section_width}%" height="{$section_height}%">

           <!-- one table per section -->
           <table width="100%" height="100%"  cellspacing="0">
            <tr>
             <td class="isp-dashboard-section-top-l"></td>
             <td class="isp-dashboard-section-top"></td>
             <td class="isp-dashboard-section-top-r"></td>
            </tr>
            <tr>
             <th class="isp-dashboard-section-left"></th>
             <!-- first row is the caption of the section -->
             <th class="isp-dashboard-section-head"><xsl:value-of select="epl:_(string(caption))"/></th>
             <th class="isp-dashboard-section-right"></th>
            </tr>
            <tr>
             <td class="isp-dashboard-section-left"></td>
             <!-- second row is the actual content of the section -->
             <td valign="center" class="isp-dashboard-section-contents">
              <xsl:variable name="section_img" select="image"/>
              <img class="db-icon" src="{$section_img}" />
              <xsl:variable name="current_item" select="."/>
              <xsl:for-each select="key('displayItem','true')[generate-id(..) = generate-id($current_item)]">
               <xsl:variable name="url" select="link/text()"/>
               <p><a href="{$url}"><xsl:value-of select="epl:_(string(display/text()))"/></a></p>
              </xsl:for-each>
             </td>
             <td class="isp-dashboard-section-right"></td>
            </tr>

            <tr>
             <td class="isp-dashboard-section-bottom-l"></td>
             <td class="isp-dashboard-section-bottom"></td>
             <td class="isp-dashboard-section-bottom-r"></td>
            </tr>

           </table>
          </td>
         </xsl:if>
        </xsl:for-each>
       </tr>
      </xsl:if>
     </xsl:for-each>
    </table>
   </body>
  </html>

</xsl:template>
</xsl:stylesheet>
