<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:fn="http://www.w3.org/2005/02/xpath-functions"
    xmlns:epl="http://www.ensim.com/epl50"
    xmlns:math="http://exslt.org/math"
    xmlns:sets="http://exslt.org/sets"
    xmlns:func="http://exslt.org/functions"
    extension-element-prefixes="func"
>

<xsl:output method="xml" indent="yes" />

<!-- This is the ISP Administrator's Dashboard XSL
     The ISP Administrator's Dashboard ($frontend/static/isp/dashboard.xml) will be passed to this
-->

<!-- This function gets an item node and checks if that node is to be displayed on the dashboard or
not. For this it checks if the service of that item is enabled or not. If no service node is present
or if service node is empty then it displays the item.
-->
<func:function name="func:isItemDisplayable">
 <xsl:param name="item_node"/>
 <xsl:variable name="ispro" select="epl:isPro()"/>
 <xsl:variable name="service" select="$item_node/service/text()"/>
 <xsl:choose>
  <xsl:when test="$item_node/child::node()[name() = 'proenabled']">
   <xsl:choose>
    <xsl:when test="$ispro = 'False'">
     <func:result select="false()"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:choose>
      <xsl:when test="$item_node/child::node()[name() = 'service'] and $item_node/service/text()">
       <xsl:choose>
        <xsl:when test="/ispdashboard/enabledservices/child::node()[name() = $service]">
         <func:result select="true()"/>
        </xsl:when>
        <xsl:otherwise>
         <func:result select="false()"/>
        </xsl:otherwise>
       </xsl:choose>
      </xsl:when>
      <xsl:otherwise>
       <func:result select="true()"/>
      </xsl:otherwise>
     </xsl:choose>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:when>
  <xsl:otherwise>
   <xsl:choose>
    <xsl:when test="$item_node/child::node()[name() = 'basicenabled']">
     <xsl:choose>
      <xsl:when test="$ispro = 'True'">
       <func:result select="false()"/>
      </xsl:when>
      <xsl:otherwise>
       <xsl:choose>
	<xsl:when test="$item_node/child::node()[name() = 'service'] and $item_node/service/text()">
	 <xsl:choose>
	  <xsl:when test="/ispdashboard/enabledservices/child::node()[name() = $service]">
	   <func:result select="true()"/>
	  </xsl:when>
	  <xsl:otherwise>
	   <func:result select="false()"/>
	  </xsl:otherwise>
	 </xsl:choose>
	</xsl:when>
	<xsl:otherwise>
	 <func:result select="true()"/>
	</xsl:otherwise>
       </xsl:choose>
      </xsl:otherwise>
     </xsl:choose>
    </xsl:when>
    <xsl:otherwise> 
     <xsl:choose>
      <xsl:when test="$item_node/child::node()[name() = 'service'] and $item_node/service/text()">
       <xsl:choose> 
	<xsl:when test="/ispdashboard/enabledservices/child::node()[name() = $service]">
	 <func:result select="true()"/>
	</xsl:when>
	<xsl:otherwise>
	 <func:result select="false()"/>
	</xsl:otherwise>
       </xsl:choose> 
      </xsl:when>
      <xsl:otherwise>
       <func:result select="true()"/> 
      </xsl:otherwise>
     </xsl:choose>
    </xsl:otherwise> 
   </xsl:choose>
  </xsl:otherwise>
 </xsl:choose>
</func:function>

<!-- This iterates over each item node in the current select and calls isItemDisplayable() function
for each item.
-->
<xsl:key name="displayItem" match="item" use="func:isItemDisplayable(.)"/>

<!-- This function checks if a section is to be displayed on the dashboard. A section has to be
displayed if there is even one item under it which is displayable.
-->
<func:function name="func:isSectionDisplayable">
 <xsl:param name="section_node"/>
 <xsl:choose>
  <xsl:when test="count(key('displayItem','true')[../caption/text() = $section_node/caption/text()]) = 0">
   <func:result select="false()"/>
  </xsl:when>
  <xsl:otherwise>
   <func:result select="true()"/>
  </xsl:otherwise>
 </xsl:choose>
</func:function>

<xsl:template match="/">
 <xsl:variable name="isp_dashboard_title" select="/ispdashboard/title/text()"/>
 <xsl:variable name="num_columns" select="/ispdashboard/columns/text()"/>
 <xsl:variable name="num_sections" select="count (/ispdashboard/section)"/>

 <!-- note: the `round' function rounds off the floating point number -->
 <xsl:variable name="num_rows" select="round ($num_sections div $num_columns)"/>

 <!-- see http://www.xml.com/pub/a/2001/05/07/xsltmath.html for some xsl math functions -->
 <xsl:variable name="section_width" select="floor (100 div $num_columns)"/>
 <xsl:variable name="section_height" select="floor (100 div $num_rows)"/>

 <html xmlns="http://www.w3.org/1999/xhtml">
  <head>
   <meta content="text/html; charset=ISO-8859-1" http-equiv="content-type" />
   <link href="/static/css/isp.global.css" type="text/css" rel="stylesheet" />
   <title><xsl:value-of select="epl:_(string(/ispdashboard/title/text()))"/></title>
   <script src="/static/js/motd.js" charset="utf-8" type="text/javascript">.</script>
  </head>

<body onload="callMotd();">
<div id="motd_message" class="motd-message"><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></div>
    <!--<xsl:variable name="updatesAvailable" select="epl:updatesAvailable()"/>
    <xsl:if test="$updatesAvailable = 'True'">
        <p><b><lang>New updates are available. Click </lang><a href="/isp/listUpdates"><lang>here</lang></a><lang> to know more.</lang></b></p>
    </xsl:if>-->

<div class="subnav-notabs">
<div class="subnav-title"><xsl:value-of select="epl:_(string(/ispdashboard/title/text()))"/></div>
</div>
<script language="Javascript">
function DShow(t)
{
    k = t.parentNode.parentNode.parentNode.parentNode.parentNode.parentNode.parentNode;
    if(t.src.indexOf("maximize.gif") != -1)
    {
        t.src = "/static/images/minimize.gif";
        k.rows[1].style.display = "";
        k.rows[2].style.display = "";
    }
    else
    {
        t.src = "/static/images/maximize.gif";
        k.rows[1].style.display = "none";
        k.rows[2].style.display = "none";
    }
}
</script>

<div class="cool-green-box">
<table class="quick_access" cellspacing="0" cellpading="0">
	<tr>
	<td width="50%" style="vertical-align: top;">
		<table class="quick_access_tools">
			<tr>
			<td colspan="3">
				<table class="qa_header" cellspacing="0" cellpadding="0">
				<tr>
				<td class="qa_header_left_corner"><img src="/static/images/blank.gif" width="3" height="1"/></td>
				<td class="qa_header_title">Tools</td>
				<td class="qa_header_min_max"><img src="/static/images/minimize.gif" onClick="DShow(this);"/></td>
				<td class="qa_header_right_corner"><img src="/static/images/blank.gif" width="3" height="1"/></td>
				</tr>
				</table>
			</td>
			</tr>
			<tr>
			<td class="quick_access_corner"><img src="/static/images/blank.gif" width="1" height="1"/></td>
			<td>
			<table class="qa_outer">
			<xsl:for-each select="/ispdashboard/section[func:isSectionDisplayable(.) = 'true']">
			<xsl:if test="(position() mod $num_columns) = 1">
			<tr>
			<!-- record the 1-based position of this element -->
			<xsl:for-each select=". | ./following-sibling::node()[(name() = 'section') and (func:isSectionDisplayable(.) = 'true')][position() &lt; $num_columns]">
			<td width="{$section_width}%" height="{$section_height}%" valign="top">
			<!-- one table per section -->
				<xsl:variable name="num_rows_in_section" select="count(item)+1"/>
				<table width="100%" cellspacing="0" class="qa_tools">
				<tr>
          			 <!-- first row is the caption of the section -->
       	   			<td class="qa_tools_img" width="32" rowspan="{$num_rows_in_section}"><xsl:variable name="section_img" select="image"/><img src="{$section_img}" class="db-icon"/></td>
				<td colspan="2" class="qa_tools_head" style="padding-left: 1px;"><xsl:value-of select="epl:_(string(caption))"/></td>
          			</tr>
           			<!-- second row is the actual content of the section -->
            			<xsl:variable name="current_item" select="."/>
            			<xsl:for-each select="key('displayItem','true')[generate-id(..) = generate-id($current_item)]">
             			<xsl:variable name="url" select="link/text()"/>
				<tr>
				<td style="padding-top: 4px;" width="10"><img src="/static/images/qa_triangle.gif"/></td>
           			<td><a href="{$url}"><xsl:value-of select="epl:_(string(display/text()))"/></a></td>
          			</tr>
            			</xsl:for-each>
	         		</table>
			</td>
			</xsl:for-each>
			</tr>
			</xsl:if>
			</xsl:for-each>
			</table>
			</td>
			<td class="quick_access_corner"><img src="/static/images/blank.gif" width="1" height="1"/></td>
			</tr>
			<tr>
			<td class="quick_access_corner"><img src="/static/images/blank.gif" width="1" height="1"/></td>
			<td class="quick_access_footer"><img src="/static/images/blank.gif" width="1" height="27"/></td>
			<td class="quick_access_corner"><img src="/static/images/blank.gif" width="1" height="1"/></td>
			</tr>
		</table>
	</td>
	<td style="padding: 0;"><img src="/static/images/blank.gif" width="10"/></td>
	<td width="50%" style="vertical-align: top;">
			<table cellspacing="0" cellpadding="0" class="quick_access_tools" width="100%">
                        <tr>
                        <td colspan="3">
                                <table class="qa_header" cellspacing="0" cellpadding="0">
                                <tr>
                                <td class="qa_header_left_corner"><img src="/static/images/blank.gif" width="3" height="1"/></td>
                                <td class="qa_header_title"><xsl:value-of select="epl:_('Server Administrator')"/></td>
                                <td class="qa_header_min_max"><img src="/static/images/minimize.gif" onClick="DShow(this);"/></td>
                                <td class="qa_header_right_corner"><img src="/static/images/blank.gif" width="3" height="1"/></td>
                                </tr>
                                </table>
                        </td>
                        </tr>
                        <tr>
                        <td class="quick_access_corner"><img src="/static/images/blank.gif" width="1" height="1"/></td>
			<td>
				<table class="qa_tools">
				<tr><td class="qa_tools_info" style="padding-top: 10px" width="30%">CP <xsl:value-of select="epl:_('Version')"/></td>
				<td class="qa_tools_info" style="padding-top: 10px">Parallels <xsl:value-of select="epl:_(string(/ispdashboard/logininfo/productType))"/> , <xsl:value-of select="epl:_(string(/ispdashboard/logininfo/version))"/></td></tr>
				<tr><td class="qa_tools_info"><xsl:value-of select="epl:_('Host Name')"/></td>
				<td class="qa_tools_info"><xsl:value-of select="/ispdashboard/appliancetop/server_name"/></td></tr>
				<tr><td class="qa_tools_info"><xsl:value-of select="epl:_('IP Address')"/></td>
				<td class="qa_tools_info"><xsl:value-of select="/ispdashboard/appliancetop/server_ip"/></td></tr>
				<tr><td class="qa_tools_info" style="padding-bottom: 10px;"><xsl:value-of select="epl:_('Domains Hosted')"/></td>
				<td class="qa_tools_info" style="padding-bottom: 10px;"><xsl:value-of select="/ispdashboard/appliancetop/domain_count"/></td></tr>
				</table>

                        </td>
                        <td class="quick_access_corner"><img src="/static/images/blank.gif" width="1" height="1"/></td>
                        </tr>
                        <tr>
                        <td class="quick_access_corner"><img src="/static/images/blank.gif" width="1" height="1"/></td>
                        <td class="quick_access_footer"><img src="/static/images/blank.gif" width="1" height="27"/></td>
                        <td class="quick_access_corner"><img src="/static/images/blank.gif" width="1" height="1"/></td>
                        </tr>
                	</table>


			<div><img src="/static/images/blank.gif" height="10" width="1"/></div>
			<table border="0" cellspacing="0" cellpadding="0"  class="quick_access_tools" width="100%">
                        <tr>
                        <td colspan="3">
                                <table class="qa_header" cellspacing="0" cellpadding="0">
                                <tr>
                                <td class="qa_header_left_corner"><img src="/static/images/blank.gif" width="3" height="1"/></td>
                                <td class="qa_header_title"><xsl:value-of select="epl:_('Server Statistics')"/></td>
                                <td class="qa_header_min_max"><img src="/static/images/minimize.gif" onClick="DShow(this);"/></td>
                                <td class="qa_header_right_corner"><img src="/static/images/blank.gif" width="3" height="1"/></td>
                                </tr>
                                </table>
                        </td>
                        </tr>
                        <tr>
                        <td class="quick_access_corner"><img src="/static/images/blank.gif" width="1" height="1"/></td>
                        <td>
				<table class="qa_tools">
				<!-- Calculates the diskquota usage in percentage to display it on the bar which represents this usage -->
				
				<xsl:variable name="disk_usage_perc" select="floor (/ispdashboard/appliancetop/disk_used div /ispdashboard/appliancetop/disk_total * 100)"/>
				<tr>
				<td class="qa_tools_info" style="padding-top: 10px;">
				<div class="disk-info">
					<div class="disk-usage-bar" style="width:{$disk_usage_perc}%"></div> 
					<div class="disk-usage-text"><xsl:value-of select="$disk_usage_perc"/>%<xsl:value-of select="epl:_(' used')"/></div>
				</div>
				</td>
				</tr>
				<tr>
				<!-- Displays actual amounts of used diskquota and total diskquota -->
				<td class="qa_tools_info"><xsl:value-of select="/ispdashboard/appliancetop/disk_used"/> / <xsl:value-of select="/ispdashboard/appliancetop/disk_total"/><span>MB<xsl:value-of select="epl:_(' Used')"/></span></td>
				</tr>
				<tr>
				<!-- Converts the uptime from seconds to days, hrs, mins format -->
				<td class="qa_tools_info" style="padding-bottom: 10px;">
				<xsl:value-of select="epl:_('Up Time')"/>: <xsl:variable name="uptime" select="/ispdashboard/appliancetop/uptime"/> <xsl:variable name="days" select="floor($uptime div 86400)"/> <xsl:value-of select="$days"/><xsl:value-of select="epl:_('Days')"/>; <xsl:variable name="hrs" select="floor($uptime mod 86400 div 3600)"/> <xsl:value-of select="$hrs"/><xsl:value-of select="epl:_('Hrs')"/>; <xsl:variable name="mins" select="floor($uptime mod 3600 div 60)"/> <xsl:value-of select="$mins"/><xsl:value-of select="epl:_('Mins')"/>
				</td>
				</tr>
				</table>
                        </td>
                        <td class="quick_access_corner"><img src="/static/images/blank.gif" width="1" height="1"/></td>
                        </tr>
                        <tr>
                        <td class="quick_access_corner"><img src="/static/images/blank.gif" width="1" height="1"/></td>
                        <td class="quick_access_footer"><img src="/static/images/blank.gif" width="1" height="27"/></td>
                        <td class="quick_access_corner"><img src="/static/images/blank.gif" width="1" height="1"/></td>
                        </tr>
                        </table>

	</td></tr>

</table>
</div>
</body>
</html>

</xsl:template>
</xsl:stylesheet>
