// The Javascript functions required to display the actionlog in the GUI

// $Id: actionlog.js,v 1.1.1.1 2008/03/03 17:50:33 aarefyev Exp $
// $Log: actionlog.js,v $
// Revision 1.1.1.1  2008/03/03 17:50:33  aarefyev
// initial import
//
// Revision 1.5.2.1  2006/08/04 08:49:23  stiwatne
// enabling liveactionlog for create site
//
// Revision 1.5  2006/02/20 06:45:10  mansoor
// the actionlog div should be hidden if there are no messages to be seen
//
// Revision 1.4  2006/01/17 06:51:27  skodre
// Reverting back to previous version
//
// Revision 1.2  2005/11/15 10:14:03  mansoor
// added live actionlog display functionality
//
// Revision 1.1  2005/11/09 12:03:32  mansoor
// actionlog GUI work done


var actionlog_requestobject = null;

function eventActionLogDetailsToggle (evt)
{
    var event;

    if (evt == null) {
        event = window.event;   // IE
    } else {
        event = evt;
    }

    var actionlog_details = document.getElementById ("actionlog:details");

    if (actionlog_details) {
        if (actionlog_details.style.display == "none") {
            actionlog_details.style.display = "block";
        } else {
            actionlog_details.style.display = "none";
        }
    }
    
}

function registerActionLogEvents ()
{
    // register an event to collapse and expand the action log details div
    var actionlog_info = document.getElementById ("actionlog:info");

    if (actionlog_info) {
        actionlog_info.onclick = eventActionLogDetailsToggle;
    }

    // if the actionlog details div does not contain any messages, then hide it
    var actionlog_details = document.getElementById ("actionlog:details");

    if (actionlog_details) {
        var actionlog_messages = actionlog_details.getElementsByTagName ("span");

        if (! actionlog_messages.length) {

            var actionlog_div = document.getElementById ("actionlog:main");
            if (actionlog_div) {
                actionlog_div.style.display = "none";
            }
        }
    }
}

// creates the XML http request object (AJAX)
// note: this function is almost the same as fliplist.js, so it's probably time to move this function to common js code
function ActionLogCreateRequestObject () {
    var req;

    /* see http://developer.apple.com/internet/webcontent/xmlhttpreq.html */

    if (window.XMLHttpRequest) {
        try {
            req = new XMLHttpRequest ();
        }
        catch (e) {
            alert ("cannot create the xml http request object");
        }
    } else if (window.ActiveXObject) {
        try {
            req = new ActiveXObject ("Msxml2.XMLHTTP");
        } catch (e) {
            try {
                req = new ActiveXObject ("Microsoft.XMLHTTP");
            } catch (e) {
                alert ("cannot create the xml http request object");
            }
        }
    }

    actionlog_requestobject = req;
}

var actionlog_live_refresh_interval = 1000;

var actionlog_id;

var xml_errors;

// In the case of `live actionlog' display, we only need to display the new log messages added since the last refresh
// The actionlog_live_status_index variable contains the current index of the status messages received
var actionlog_live_status_index = 0;

// Registers an event to automatically refresh the live action log window
function registerLiveActionLogEvent (interval, id)
{
    ActionLogCreateRequestObject ();
    actionlog_id = id;
    actionlog_live_refresh_interval = interval;

    fetchActionLog ();
}

function fetchActionLog ()
{
    actionlog_requestobject.open ("POST", "/isp/viewactionlog", true);
    actionlog_requestobject.setRequestHeader ("Content-type", "application/x-www-form-urlencoded");
    actionlog_requestobject.onreadystatechange = refreshActionLog;
    actionlog_requestobject.send ("id=" + actionlog_id);
    return;
}

function refreshActionLog ()
{
    if (actionlog_requestobject.readyState == 4) {
        if (actionlog_requestobject.status == 200) {
            /* 200 OK */

            // alert (actionlog_requestobject.responseText);

            // load the xml()ized representation of the action log
            var xmldoc = load_xml (actionlog_requestobject.responseText);

            // <statuslist xmlns="http://www.ensim.com/lvh/"><severity>INFO</severity><msglist><status><severity>WARNING</severity><msg>this is a warning</msg></status><status><severity>INFO</severity><msg>this is information</msg></status><status><severity>ERROR</severity><msg>this is an error</msg></status></msglist></statuslist>

            var msglistnode = xmldoc.docNode.getElements ("msglist") [0];
            var statusnodes = msglistnode.getElements ("status");
            var completednode = xmldoc.docNode.getElements ("completed") [0];

            var livedetails = document.getElementById ("actionlog:details:live");

            for (i =actionlog_live_status_index; i <statusnodes.length; ++i) {

                // start attaching the nodes to the details div
                var p = document.createElement ("p");

                // get a handle to the <status> node
                var statusnode = statusnodes [i];

                // create the loglevel span
                var loglevel_span = document.createElement ("span");

                var severity = statusnode.getElements ("severity")[0].getText ();
                var loglevel = statusnode.getElements ("loglevel")[0].getText ();

                loglevel_span.innerHTML = severity; // severity should already be internationalized
                loglevel_span.className = "loglevel" + loglevel;

                p.appendChild (loglevel_span);

                // now create a para for the actual status text
                var msg = statusnode.getElements ("msg")[0].getText ();
                var statustext_span = document.createElement ("span");
                statustext_span.innerHTML = msg;

                p.appendChild (statustext_span);

                livedetails.appendChild (p);
            }

            // set the current status pointer to point to just beyond the end of what we received
            //actionlog_live_status_index = statusnodes.length;

            // alert (actionlog_requestobject.responseText);
            // setTimeout (fetchActionLog, actionlog_live_refresh_interval);

            if (completednode.getText () == "False") {
                // alert ("this action has not yet finished, should refresh in " + actionlog_live_refresh_interval + " ms");
                setTimeout (fetchActionLog, actionlog_live_refresh_interval);
            }
        } // end if (HTTP 200 OK)
        else {
            alert ("There was an error fetching the requested URL: " + actionlog_requestobject.status)
        }
    }
}

function xml_error (str) {
    xml_errors += str;
}

function load_xml (xmltext) {
    var xd = new XMLDoc (xmltext, xml_errors);  /* XML for <script> */
    if (xd.hasErrors) {
        alert ("The XML document has errors");
    }
    return xd;
}


