// The Searchable, Sortable, Data Grid based, Dynamic, AJAX based, Flip List Control :) 
// Author: Mansoor Peerbhoy

// $Id: fliplist.js,v 1.1.1.1 2008/03/03 17:50:33 aarefyev Exp $
// $Name:  $


// flColumns holds an array of the column names
var flColumns = null;

// flColumnTitles holds an array of the display names of the columns
var flColumnTitles = null;

// flItemsPerPage is the number of items to be displayed per page
var flItemsPerPage = null;

// flCurrentPage is the page that we are currently at (1-based for dummies)
var flCurrentPage = 1;

// The maximum number of entries. This indicates the number of entries in the data grid
var flMaxEntries = null;

// ahh ... the AJAX object
var flRequest = null;

// a global variable holding the results of xml content parsing from the backend
var xml_errors = "";

// the constraints (or transforms) map. this is an associative array (hashtable) which is the basis for content filtering
var flConstraints = null;

// windowSize stores the value of items per page for each fliplist. This is saved in session so that
// it can be retained across page reloads.
var windowSize;

// another associative array that holds the mapping of the name of the column header <anchor> to the corresponding <img> id
var flSortColumnImageMap = null;

// the login role (is either "isp" or "reseller" or "site" or "user")
var flLoginRole = "";

// the name of the flip list view, as it is saved on the server side. For example, "SiteListView"
var flViewName = "";

// the text of the message that is to be displayed if the flip list has no contents
var flNoItemsText = "There are no items in this list";

// error message to be displayed if an error occurs while creating a request object
var createRequestObjErr = "cannot create the xml http request object";

//confirmation message to be displayed when delete event is triggered
var deleteConfirmationMsg = "Click OK to complete this action";

//error message to be displayed if there is error in the xml document
var xmlErr = "The XML document has errors";

// the event confirmation map
var flEventConfirmationMap = new Array ();

/* some utility functions */

function min (x1, x2) {
    if (x1 < x2) {
        return x1;
    } else {
        return x2;
    }
}

function max (x1, x2) {
    if (x1 > x2) {
        return x1;
    } else {
        return x2;
    }
}

function initializeFlipListViewName (x) {
    flViewName = x;
}

function initializeFlipListLoginRole (x) {
    flLoginRole = x;
}

function initializeNoItemsText (x) {
    flNoItemsText = x;
}


function initializeCreateRequestObjErr (x) {
    createRequestObjErr = x;
}

function initializeDeleteConfirmationMsg (x) {
    deleteConfirmationMsg = x;
}

function initializeXmlErr (x) {
    xmlErr = x;
}

function initializeFlipListColumns (x) {
    /* an easier way to do this ? */
    flColumns = new Array (x.length);
    for (i =0; i <x.length; ++i) {
        flColumns[i] = x[i];
    }
}

function initializeFlipListColumnDisplays (x) {
    /* an easier way to do this ? */
    flColumnTitles = new Array (x.length);
    for (i =0; i <x.length; ++i) {
        flColumnTitles[i] = x[i];
    }
}

function initializeSortColumnImageMap () {
    flSortColumnImageMap = new Object ();
    for (i =0; i <flColumns.length; ++i) {
        flSortColumnImageMap ["flcolumn:" + flColumns[i]] = "sortimg:" + flColumns[i];
    }
}

function initializeSortArrows (sort_column) {
    for (i =0; i <flColumns.length; ++i) {
        var sortimg = document.getElementById ("sortimg:" + flColumns[i]);
        if (sortimg) {
            if (sort_column != "" && sort_column == flColumns[i]) {
                sortimg.style.visibility = "visible";
            }
            else {
                sortimg.style.visibility = "hidden";
            }
        }
    }
}

function toggleSortImage (imgid) {
    var sortimg = document.getElementById (imgid);

    if (sortimg) {
        if (sortimg.style.visibility == "hidden") {
            sortimg.style.visibility = "visible";
        } else {
            // already visible

            // alert (sortimg.src);
            if (sortimg.src.search("arrow-up.gif") != -1) {
                sortimg.src = "/static/images/arrow-down.gif";
            } else {
                sortimg.src = "/static/images/arrow-up.gif";
            }
        }
        // now hide the others
        for (var key in flSortColumnImageMap) {
            if (flSortColumnImageMap[key] != imgid) {
                var otherimg = document.getElementById (flSortColumnImageMap[key]);
                if (otherimg) {
                    otherimg.style.visibility = "hidden";
                }
            }
        }
    }
}

function setFlipListMaxEntries (x) {
    flMaxEntries = x;
}

function setFlipListSize (x) {
    flItemsPerPage = x;
}

function setCurrentPage (x) {
    flCurrentPage = x;
}

function createRequestObject () {
    var req;

    /* see http://developer.apple.com/internet/webcontent/xmlhttpreq.html */

    if (window.XMLHttpRequest) {
        try {
            req = new XMLHttpRequest ();
        }
        catch (e) {
            alert (createRequestObjErr);
        }
    } else if (window.ActiveXObject) {
        try {
            req = new ActiveXObject ("Msxml2.XMLHTTP");
        } catch (e) {
            try {
                req = new ActiveXObject ("Microsoft.XMLHTTP");
            } catch (e) {
                alert (createRequestObjErr);
            }
        }
    }

    flRequest = req;
}

function calculateMaximumPage () {
    // this function tells you the maximum page number that you can go to
    if (flMaxEntries == 0) {
        return 1;
    } else {
        if ( ((flMaxEntries/flItemsPerPage) * flItemsPerPage) <= flMaxEntries) {
            // there is a remainder
            return parseInt((flMaxEntries/flItemsPerPage) + 1);
        } else {
            return parseInt((flMaxEntries/flItemsPerPage));
        }
    }
}


function eventPageFlip (evt) {
    var event;
    var sourceNode;
    var needReload = true;

    if (evt == null) {
        event = window.event;   // IE
        sourceNode = event.srcElement;
    } else {
        event = evt;
        sourceNode = event.target;
    }

    var id = sourceNode.id;

    if (id == "pagefirst") {
        if (flCurrentPage == 1) {
            // we are already at page number 1
            needReload = false;
        }
        flCurrentPage = 1;
    }

    if (id == "pageprev") {
        if (flCurrentPage > 1) {
            flCurrentPage = flCurrentPage -1;
        } else {
            // cannot go before first page
            needReload = false;
        }
    }

    if (id == "pagenext") {
        if (flCurrentPage < calculateMaximumPage ()) {
            flCurrentPage = flCurrentPage +1;
        } else {
            // cannot go beyond last page
            needReload = false;
        }
    }

    if (id == "pagelast") {
        if (flCurrentPage == calculateMaximumPage ()) {
            // we are already at the last page
            needReload = false;
        }
        flCurrentPage = calculateMaximumPage ();
    }

    constraintPageNumber ();

    if (needReload) {
        fetchFlipListContents ();
    }
}


function populateFlipList ()
{
    if (flRequest.readyState == 4) {
        if (flRequest.status == 200) {
            /* 200 OK */
            // alert (flRequest.responseText);
            xmldoc = load_xml (flRequest.responseText);

            /* we need to start iterating over the <entry> nodes */
            var entries = xmldoc.docNode.getElements ("entry");
            //alert ("<entry> nodes found: " + entries.length);

            // grab the table object
            var table = document.getElementById ("fliplist");

            // start filling in the rows
            for (i =0; i <min(entries.length,flItemsPerPage); ++i) {
                var row = table.insertRow (table.rows.length);
                var entrynode = entries[i];
                for (j =0; j <flColumns.length; ++j) {
                    var cellnode = entrynode.getElements (flColumns[j])[0];
                    var cell = row.insertCell (j);
                    cell.innerHTML = cellnode.getText ();

                    if ((i % 2) == 0) {
                        cell.className = "fliplist-even";
                    } else {
                        cell.className = "fliplist-odd";
                    }
                }
            }

            if (entries.length == 0) {
                var row = table.insertRow (table.rows.length);
                var cell = row.insertCell (0);
                cell.colSpan = flColumns.length;
                cell.innerHTML = flNoItemsText;
            }

            // set the current page number
            var currentpagespan = document.getElementById ("currentpage");
            if (currentpagespan) {
                currentpagespan.innerHTML = flCurrentPage;
            }

            // setting the last page number
            var totalpages = document.getElementById ("totalpages");
            if (totalpages) {
                totalpages.innerHTML = calculateMaximumPage ();
            }
            
            if (document.getElementById("pagefirst")) {
                if (flCurrentPage == 1) {
                // we are already at page number 1
                    document.getElementById("pagefirst").src = "/static/images/arrow_first_disabled.gif"
                }
                else
                    document.getElementById("pagefirst").src = "/static/images/arrow_first.gif"
            }

            if (document.getElementById("pageprev")) {
                if (flCurrentPage <= 1) {
                    // cannot go before first page
                    document.getElementById("pageprev").src = "/static/images/arrow_prev_disabled.gif"
                }
                else
                    document.getElementById("pageprev").src = "/static/images/arrow_prev.gif"
            }
            var maxpage = calculateMaximumPage ();
            if (document.getElementById("pagenext")) {
                if (flCurrentPage == parseInt(maxpage)) {
                // cannot go beyond last page
                    document.getElementById("pagenext").src = "/static/images/arrow_next_disabled.gif"
                }
                else
                    document.getElementById("pagenext").src = "/static/images/arrow_next.gif"
            }

            if (document.getElementById("pagelast")) {
                if (flCurrentPage == parseInt(maxpage)) {
                    // we are already at the last page
                    document.getElementById("pagelast").src = "/static/images/arrow_last_disabled.gif"
                }
                else
                    document.getElementById("pagelast").src = "/static/images/arrow_last.gif"
            }


            processDynamicCellEvents ();
        }   // endif (status == 200)
    }   // endif (readyState == 4)
}

function initializeEventConfirmation (x) {
    flEventConfirmationMap = x;
}


function processDynamicCellEvents () {
    for (var t = 0; t < flEventConfirmationMap.length; ++t) {
        var elements = document.getElementsByTagName (flEventConfirmationMap[t][0]);
        for (var i = 0; i < elements.length; ++i) {
            var nodename = elements[i].getAttribute ("name");
            if ((nodename) && (nodename.indexOf (flEventConfirmationMap [t][1]) == 0)) {
                elements[i].onclick = eventDeleteConfirmation;
            }
        }
    }
}

function eventDeleteConfirmation (evt) {
    var event;
    var sourceNode;
    var confirmationMessage = deleteConfirmationMsg;

    if (evt == null) {
        event = window.event;   // IE
        sourceNode = event.srcElement;
    } else {
        event = evt;
        sourceNode = event.target;
    }

    //alert ("my source node is : " + sourceNode);

    var sourcenodeName = sourceNode.getAttribute ("name");
    if (sourcenodeName) {
        //alert ("examining sourcenodeName: " + sourcenodeName);
        for (var i = 0; i < flEventConfirmationMap.length; ++i) {
            //alert ("flipping thru: " + flEventConfirmationMap [i][1]);
            if (sourcenodeName.indexOf (flEventConfirmationMap[i][1]) == 0) {
                confirmationMessage = flEventConfirmationMap[i][2];
                break;
            }
        }
    }

    return confirm (confirmationMessage);
}

function clearFlipList () {
    var table = document.getElementById ("fliplist");
    while (table.rows.length > 1) {
        table.deleteRow (table.rows.length -1);
    }
}

//This function is used for creating a name/value in the session.
//It is required to store the items per page value in the session so that it can be retained across
//page reloads.
function setCookieValue (cookieName, cookieValue) {
    document.cookie = escape(cookieName) + "=" + escape(cookieValue) + "; path=/";
    return document.cookie;
}

//This function is used for getting the cookie value from the session.
//From the name/value pair name is passed to this function for getting the value associated with it.
function getCookieValue (cookieName) {
    var exp = new RegExp (escape(cookieName) + "=([^;]+)");
    if (exp.test (document.cookie + ";")) {
        exp.exec (document.cookie + ";");
        return unescape(RegExp.$1);
    }
    else return false;
}
function fetchFlipListContents () {
    clearFlipList ();
    flRequest.open ("POST", "/" + flLoginRole + "/viewentrylist", true);
    flRequest.setRequestHeader ("Content-Type", "application/x-www-form-urlencoded");
    flRequest.onreadystatechange = populateFlipList;
    var poststring = "viewName=" + flViewName + "&" + buildFlipListConstraints ();
    flRequest.send (poststring);
    return;
}

function xml_error (str) {
    xml_errors += str;
}

function load_xml (xmltext) {
    var xd = new XMLDoc (xmltext, xml_errors);  /* XML for <script> */
    if (xd.hasErrors) {
        alert (xmlErr);
    }
    return xd;
}

// buildFlipListConstraints:
// The idea behind this function is to examine the current state of the flip list, in order 
// that when we eventually AJAX back to the server side, to fetch the data grid, we know how
// many items we need to fetch, from which page to start, etc.
// The constraints take the form of `name=value' strings, which are the most natural way to 
// pass named arguments to the backend.
// In fact, all the constraints that are built from this function are eventually passed to the 
// datagrid retriever function. These constraints are then examined at the server side, to 
// filter the list of entries that are sent back to the browser

function buildFlipListConstraints () {
    flConstraints = new Object ();
    constraintPageNumber ();
    constraintWindowSize ();
    constraintSort ();
    constraintSearch ();

    return getFlipListConstraints ();
}

function getFlipListConstraints () {
    var httppostConstraints = "";
    for (var constraint in flConstraints) {
        if (flConstraints[constraint]) {
            var postvariable = constraint + "=" + flConstraints[constraint];
            if (httppostConstraints == "") {
                httppostConstraints = postvariable;
            } else {
                httppostConstraints = httppostConstraints + "&" + postvariable;
            }
        }
    }
    return httppostConstraints;
}

function constraintPageNumber () {
    flConstraints['page'] = flCurrentPage;
}

function constraintWindowSize () {
    var itemspp = document.getElementById ("itemspp");
    if (itemspp) {
        flConstraints['window'] = itemspp.options[itemspp.selectedIndex].text;
    }
}

function constraintSort () {
    flConstraints['asort'] = null;
    flConstraints['dsort'] = null;
    for (i =0; i <flColumns.length; ++i) {
        var col = flColumns[i];
        var colhead = 'flcolumn:' + col;
        var sortimgid = flSortColumnImageMap[colhead];
        var sortimg = document.getElementById (sortimgid);

        if (sortimg) {
            if (sortimg.style.visibility == "visible") {
                if (sortimg.src.search("arrow-up.gif") != -1) {
                    flConstraints['asort'] = col;
                }
                if (sortimg.src.search("arrow-down.gif") != -1) {
                    flConstraints['dsort'] = col;
                }
            }
        }
    }
}

function constraintSearch () {
    var searchby = document.getElementById ("searchby");
    if (searchby != null) {
    var searchwhat = searchby.options[searchby.selectedIndex].value;
    var searchbox = document.getElementById ("searchtext");
    var searchfor = searchbox.value;

    if (searchfor) {
        // alert ("searching for " + searchwhat + ":" + searchfor);
        flConstraints['search'] = searchwhat + ":" + searchfor;
        // remember, on a search, people usually like to be landed at the first page of the search result
        flCurrentPage = 1;
        constraintPageNumber ();
    } else {
        flConstraints['search'] = null;
    }
    }
}

function eventSortColumn (evt) {
    var event;
    var sourceNode;

    if (evt == null) {
        event = window.event;   // IE
        sourceNode = event.srcElement;
    } else {
        event = evt;
        sourceNode = event.target;
    }

    // alert (sourceNode.id);
    // alert (flSortColumnImageMap[sourceNode.id]);

    toggleSortImage (flSortColumnImageMap[sourceNode.id]);

    constraintSort ();
    fetchFlipListContents ();
}

function eventPageSizeChange (evt) {
    var event;
    var sourceNode;

    if (evt == null) {
        event = window.event;   // IE
        sourceNode = event.srcElement;
    } else {
        event = evt;
        sourceNode = event.target;
    }

    flItemsPerPage = sourceNode.options[sourceNode.selectedIndex].text; // atoi required ?
    setCookieValue (flViewName, flItemsPerPage);

    // alert (sourceNode.options[sourceNode.selectedIndex].text);
    constraintWindowSize ();
    flCurrentPage = 1; 
    fetchFlipListContents ();
}

function eventPressSearchButton (evt) {
    var event;
    var sourceNode;
    if (evt == null) {
        event = window.event;
        sourceNode = event.srcElement;
    }
    else {
        event = evt;
        sourceNode = event.target;
    }
    
    keyCode = event.keyCode;
    if (keyCode == 13) {
        if (sourceNode == document.getElementById ("searchtext")) {
            document.getElementById ("searchbutton").click();
            //event.stopPropagation();
        }
    }
}

function eventSearch (evt) {
    var sourceNode = document.getElementById ("searchtext");
    //search needs to be case insensitive.The string to be searched should be first converted to
    //lower case.
    document.getElementById("searchtext").value = document.getElementById ("searchtext").value.toLowerCase();
    //alert(document.getElementById("searchtext").value);
    fetchFlipListContents ();
}

function eventShowall (evt) {
    var sourceNode = document.getElementById ("searchtext");
    sourceNode.value = "";  // clearing the search bar should show all the contents
    fetchFlipListContents ();
}

//function keyPressSearch(keyCode) {
//    if(keyCode == 13) {
//        searchbutton.click();
//    }
//}

function registerFliplistEvents () {
    // register events for column sorting
    for (i =0; i <flColumns.length; ++i) {
        var column_target = document.getElementById ("flcolumn:" + flColumns[i]);
        if (column_target) {
            column_target.onclick = eventSortColumn;    // register the onclick event -- potentially cross browser issues ?
        }
    }

    // register events for page size changing
    var itemspp = document.getElementById ("itemspp");
    if (itemspp) {
        itemspp.onchange = eventPageSizeChange;
    }

    // register events for page flipping (first, previous, next, last)
    var pagefirst = document.getElementById ("pagefirst");
    var pageprev = document.getElementById ("pageprev");
    var pagenext = document.getElementById ("pagenext");
    var pagelast = document.getElementById ("pagelast");

    if (pagefirst) pagefirst.onclick = eventPageFlip;
    if (pageprev) pageprev.onclick = eventPageFlip;
    if (pagenext) pagenext.onclick = eventPageFlip;
    if (pagelast) pagelast.onclick = eventPageFlip;

    var searchbutton = document.getElementById ("searchbutton");
    if (searchbutton) searchbutton.onclick = eventSearch;

    var showall = document.getElementById ("showall");
    if (showall) showall.onclick = eventShowall;

    document.onkeyup = eventPressSearchButton;
}

function initializeItemsPerPage () {
    /* manipulates the selected index of the items per page dropdown, depending upon the value in flItemsPerPage */
    var items_per_page = flItemsPerPage;

    var itemspp = document.getElementById ("itemspp");
    itemspp.selectedIndex = find_element_in_array (itemspp.options, items_per_page);

    //alert ("selectedindex is:");
    //alert (itemspp.selectedIndex);
}

function find_element_in_array (arr, i) {
    /* returns the position of the element `i' inside the array `arr', 0 if not found */
    var pos = 0;

    for (var n=0; n < arr.length; ++n) {
        if (arr[n].text == i) {
            pos = n;
            break;
        }
    }

    return pos;
}

function loadItemsPerPage () {
    // returns the previously saved (in cookie) items per page, or a default value (10) otherwise

    var viewname = flViewName;
    var savedItemsPerPage = getCookieValue (viewname);
    if (! savedItemsPerPage) {
        savedItemsPerPage = 10;
        setCookieValue (viewname, savedItemsPerPage);
    }
    return savedItemsPerPage;
}

