/*  This javascript code mainly deals with the different functions required in order to implement a chain of 
    pages linked together by a "wizard" framework.

    Here's the idea behind the wizard framework:
    Typically, when we talk about a "wizard" (at least at Ensim), what we mean is an ordered sequence of pages
    that can be sequentially filled out by the user

    The pages are linked together by the standard "Previous", "Next", and "Finish" buttons, with the obvious 
    significance.

    To consider this model from an abstract view, let us consider the following proposal as the 'functional requirement'
    of a wizard:

    1. The primary input is an ordered set of pages P1, P2, P3 .... Pn. These are the pages to be linked.
    2. If the current content of the wizard is page Pi (i<n), then clicking the 'Next' button should take you to Pi+1
    3. If the current content of the wizard is page Pi (i>1), then clicking the 'Previous' button should take you to Pi-1
    4. You cannot click 'Previous' when you are at the first page, P1.
    5. You cannot click 'Next' when you are at the last page, Pn.
    6. You cannot click 'Finish' unless you are at the last page, Pn. (* some people may not like this feature)
    7. If you move 'Next' from page Pi to Pi+1, then all the input variables that were entered from page P1 to page Pi
       must be submitted (POSTed) to page Pi+1
 */

var pageIndex = 0;

/* List of pages that the wizard needs to iterate over */
var wizardPages = null;

var xmlhttp = null;

function createRequestObject () {
    var req;

    /* see http://developer.apple.com/internet/webcontent/xmlhttpreq.html */

    if (window.XMLHttpRequest) {
        try {
            req = new XMLHttpRequest ();
        }
        catch (e) {
            alert ("cannot create the xml http request object");
        }
    } else if (window.ActiveXObject) {
        try {
            req = new ActiveXObject ("Msxml2.XMLHTTP");
        } catch (e) {
            try {
                req = new ActiveXObject ("Microsoft.XMLHTTP");
            } catch (e) {
                alert ("cannot create the xml http request object");
            }
        }
    }

    xmlhttp = req;
}

function initializeWizard (urls)
{
    /* maybe an easier way to do this */
    wizardPages = new Array (urls.length);
    for (i =0; i <wizardPages.length; ++i) {
        wizardPages[i] = urls[i];
    }

    pageIndex = 0;

    createRequestObject ();
}

function advanceNextPage () 
{
    /* the variable 'this' does not work here, so we must needs use the xmlhttp global :( */
    if (xmlhttp.readyState == 4) {
        if (xmlhttp.status == 200) {
            pageIndex ++;
            var wizard = document.getElementById ("wizardcontent");
            wizard.innerHTML = xmlhttp.responseText;
        }
    }
}

/* gets the next page in sequence */
function fetchNextPage ()
{
    if (!wizardPages) {
        alert ("The wizard did not initialize (programmer error)");
        return;
    }

    if (pageIndex >= wizardPages.length) {
        alert ("Sorry, reached the end of the page sequence");
    }

    createRequestObject ();
    xmlhttp.open ("GET", wizardPages[pageIndex], true);

    xmlhttp.onreadystatechange = advanceNextPage;

    xmlhttp.send ("");

    return; /* true ? */
}

/* This function generates all the data that has to be posted to the individual pages in the chain */
function generatePOSTData ()
{
}
