# --------------------------------------------------------------------------
###
#
# Copyright (c) Ensim Corporation 2000, 2001   All Rights Reserved.
#
# This software is furnished under a license and may be used and copied
# only  in  accordance  with  the  terms  of such  license and with the
# inclusion of the above copyright notice. This software or any other
# copies thereof may not be provided or otherwise made available to any
# other person. No title to and ownership of the software is hereby
# transferred.
#
# The information in this software is subject to change without notice
# and  should  not be  construed  as  a commitment by Ensim Corporation.
# Ensim assumes no responsibility for the use or  reliability  of its
# software on equipment which is not supplied by Ensim.
#
# $Id: ZoneParser.pm,v 1.1.1.1 2008/03/01 00:21:33 aarefyev Exp $
# --------------------------------------------------------------------------

package ZoneParser;

use strict;

use BIND::Conf_Parser;
our @ISA = qw(BIND::Conf_Parser);
use Data::Dumper;

use constant DEFAULT_CONTROLS_PORT => 953;

sub new {
    my $class = shift;
    my $self = { };
    bless $self, $class;
    
    $self->{zones} = {};
    $self->{_keys} = {};    # because keys is a reserved word in perl
    $self->{options} = {};
    $self;
}

sub handle_zone {
    my ($self, $name, $class, $type, $options) = @_;
    
    my %zoneInfo = ();
    $self->{zones}->{$name} = $options;
}

sub handle_key {
    my ($self, $name, $algo, $secret) = @_;
    $self->{_keys}->{$name} = $secret;  # algo is always hmac-md5
}

sub handle_control {
    my ($self, $proto, $control) = @_;
}

sub handle_option {
    my $self = shift;
    $self->{options}->{$_[0]} = $_[1];
}

sub zones {
    my $self = shift;
    return $self->{zones};
}

####
# Overrides the default implementation to support BIND 9.x 
# style controls syntax.
####
sub parse_controls($) {
    my $self = shift;

    $self->expect('{', "following `controls'");
    while(1) {
	$self->expect([ [ qw(inet) ], ';' ], "reading `controls'");
	last if $self->{_token} eq ';';
        my($addr, $port, $addrMatchList, $keyList);
        $self->expect([ BIND::Conf_Parser::IPADDR, '*' ], "following `inet'");
        $addr = $self->{_token} eq '*' ? 0 : $self->{_data};
        $self->expect([ [ 'port', 'allow' ] ], "following 'IPADDR'");
        # port number is optional
        if ($self->{_data} ne 'allow') {
	    $self->expect([ BIND::Conf_Parser::NUMBER ], "following 'port'");
            $port = 0 + $self->{_data};
            $self->expect([["allow"]], "following port number");
        } else {
            $port = DEFAULT_CONTROLS_PORT;
        }
        $addrMatchList = $self->parse_addrmatchlist("following `allow'");
        
        $self->expect([['keys']], "expecting `keys'");
        $keyList = $self->parse_keyList("following `keys'");

        $self->handle_control("inet", [ $addr, $port, $addrMatchList,
                                        $keyList]);
    }
    $self->expect('}', "closing `controls'");
    $self->expect(';', "finishing `controls'");
}

sub parse_keyList ($$) {
    my ($self, $mess) = @_;

    $self->expect('{', $mess);
    my(@keys);
    while (1) {
        $self->expect([ BIND::Conf_Parser::WORD, 
                      BIND::Conf_Parser::STRING, '}' ],
                      $mess);
        last if $self->{_token} eq '}';
        push @keys, $self->{_data};
	$self->expect(';', "reading key list");
    }

    return \@keys;
}

sub parse_addrmatchlist($$;$) {
    my($self, $mess, $nolex) = @_;
    $self->expect('{', $mess, $nolex);
    my(@items, $negated, $data);
    while(1) {
	$negated = 0;
	$self->expect([ BIND::Conf_Parser::IPADDR, BIND::Conf_Parser::NUMBER, 
		      BIND::Conf_Parser::WORD, BIND::Conf_Parser::STRING, 
			'!', '{', '}' ], $mess);
	last if $self->{_token} eq '}';
	if ($self->{_token} eq '!') {
	    $negated = 1;
	    $self->expect([ BIND::Conf_Parser::IPADDR, 
			  BIND::Conf_Parser::NUMBER, BIND::Conf_Parser::WORD, 
			  BIND::Conf_Parser::STRING, '{' ],
			  "following `!'");
	}
	if ($self->{_token} eq '{') {
	    push @items, [ $negated, $self->parse_addrmatchlist($mess, 1) ];
	    next
	}
	if ($self->{_token} eq BIND::Conf_Parser::WORD) {
	    if ($self->{_data} eq "key") {
		###
		# this is key key_id construct, we need to find the key_id
		###
		$self->expect([ BIND::Conf_Parser::STRING, 
			      BIND::Conf_Parser::WORD ], $mess);
		push @items, [ $negated, "key", $self->{_data} ];
	    } else {
		push @items, [ $negated, "acl", $self->{_data} ];
	    }
	    next
	}	
	if ($self->{_token} eq BIND::Conf_Parser::STRING) {
	    push @items, [ $negated, "acl", $self->{_data} ];
	    next
	}
	$data = $self->{_data};
	$self->expect( $self->{_token} eq BIND::Conf_Parser::NUMBER ? '/' : [ '/', ';' ], $mess);
	if ($self->{_token} eq ';') {
	    push @items, [ $negated, $data ];
	    redo	# we already slurped the ';'
	}
	$self->expect(BIND::Conf_Parser::NUMBER, "following `/'");
	push @items, [ $negated, $data, $self->{_data} ];
    } continue {
	$self->expect(';', $mess);
    }
    return \@items
}

sub parse_logging_channel($) {
    my $self = shift;
    $self->expect([ BIND::Conf_Parser::WORD, BIND::Conf_Parser::STRING ], "following `channel'");
    my($name) = $self->{_data};
    $self->expect('{', "following `channel $name'");
    my(%options, $temp);
    while (1) {
	$self->expect([ [ qw(file syslog null severity print-category
			     print-severity print-time) ], '}' ],
		      "reading channel `$name'");
	last if $self->{_token} eq '}';
	$temp = $self->{_data};
	if ($temp =~ /^print-/) {
	    $options{$temp} = $self->parse_bool("following `$temp'");
	} elsif ($temp eq "null") {
	    $self->choke("Destination already specified for channel `$name'")
			if exists $options{dest};
	    $options{dest} = "null";
	} elsif ($temp eq "file") {
	    $self->choke("Destination already specified for channel `$name'")
			if exists $options{dest};
	    $self->expect(BIND::Conf_Parser::STRING, "following `file'");
	    $options{dest} = $self->{_data};
	    while(1) {
		$self->expect([ [ qw(versions size) ], ';' ],
			    "reading channel `$name' file specifier");
		last if $self->{_token} eq ';';
		if ($self->{_data} eq "size") {
		    $options{size} = $self->parse_size("following `size'");
		} else { # versions
		    $self->expect([ BIND::Conf_Parser::WORD, BIND::Conf_Parser::NUMBER ], "following `versions'");
		    if ($self->{_token} eq BIND::Conf_Parser::NUMBER) {
			$options{versions} = $self->{_data};
		    } elsif ($self->{_data} eq "unlimited") {
			$options{versions} = -1;
		    } else { $self->choke("Unexpected identifier following ",
				     "`versions' at ", $self->where);
		    }
		}
	    }
	    redo # already slurped ';'
	} elsif ($temp eq "syslog") {
	    $self->choke("Destination already specified for channel `$name'")
			if exists $options{dest};
	    $self->expect([[qw(kern user mail daemon auth syslog lpr news
			       uucp cron authpriv ftp local0 local1 local2
			       local3 local4 local5 local6 local7)]],
			  "following `syslog'");

	    $options{dest} = "syslog " . $self->{_data};
	} elsif ($temp eq "severity") {
	    $self->expect([[qw(critical error warning notice info debug
			       dynamic)]], "following `severity'");
	    $options{severity} = $self->{_data};
	    if ($options{severity} eq "debug") {
		$self->expect([ BIND::Conf_Parser::NUMBER, ';' ], "reading channel `$name'");
		if ($self->{_token} eq BIND::Conf_Parser::NUMBER) {
		    $options{severity} .= " " . $self->{_data};
		} else {
		    redo # already slurped the ';'
		}
	    }
	}
    } continue {
	$self->expect(';', "reading channel `$name'");
    }
    $self->expect(';', "to finish channel `$name'");
    $self->handle_logging_channel($name, \%options);
}


1;
