# dnsLog -- A package that handles the DNS logging from various modules
# 

# $Id: dnsLog.pm,v 1.1.1.1 2008/03/01 00:21:33 aarefyev Exp $

package dnsLog;
use strict;
require Exporter;

our @ISA = qw (Exporter);
our @EXPORT_OK = qw (logdns);

use lib ($ENV{'OCW_SVCPATH'} || "/usr/lib/opcenter")."/bind";
use lib ($ENV{'OCW_SVCPATH'} || "/usr/lib/opcenter")."/cmdline_common";

use dnsOptions;
use DBI qw (:sql_types);

# Constants used by this module
# 

my $database_handle;

# function logdns:
#   logs a DNS action into the dns_log table of appldb.
# argument (hash ref):
# keys expected in hash:
# {action}          The action (ADD/DELETE)
# {zone}            The zone being operated upon
# {type}            Type of record (A/MX/PTR/CNAME/AAAA/SRV/TXT)
# {host}            The LHS of the record
# {data}            The RHS of the record
# {extra}           Some extra parameters
# {reserved1}       reserved1
# {reserved2}       reserved2
sub logdns (\%) {
    my $rs = shift;

    if ($dnsOptions::_log == 0) { return; }

    my $query = qq { INSERT INTO dns_log (site_id, action, zonename, record_type, hostname, data)
                     VALUES (?, ?, ?, ?, ?, ?) };

    my $sth = $database_handle->prepare ( $query );

    eval {
        $sth->bind_param (1, $dnsOptions::siteid || 0, SQL_INTEGER);
        $sth->bind_param (2, $rs->{action} || "", SQL_VARCHAR);
        $sth->bind_param (3, $rs->{zone} || "", SQL_VARCHAR);
        $sth->bind_param (4, $rs->{type} || "", SQL_VARCHAR);
        $sth->bind_param (5, $rs->{host} || "", SQL_VARCHAR);
        $sth->bind_param (6, $rs->{data} || "", SQL_VARCHAR);

        $sth->execute ();
        $database_handle->commit ();
    };
}

BEGIN {
    $database_handle = DBI->connect ("dbi:Pg:dbname=appldb", "", "", { RaiseError => 1, AutoCommit => 0 });
    if (($#ARGV != -1) && ("$ARGV[0]" eq 'dnsLog.pm') && ("$ARGV[1]" eq 'test')) {
        print "Adding a sample recordset to dns_log\n";
        $dnsOptions::_log = 1;
        my %data = ( action => 'add', zone => 'ensim.com', type => 'A', host => 'www', data => '10.10.10.10' );
        logdns (%data);
    }
}

END {
    $database_handle->disconnect ();
}

1;
